<?php



namespace WpieApp\Core\Helpers;

defined( 'WPIE__FILE__' ) || exit;


trait Sanitize {

        
        public static function sanitizeKey( $str = "" ) {

                if ( is_array( $str ) ) {
                        return array_map( [ __CLASS__, "sanitizeKey" ], $str );
                }

                if ( is_numeric( $str ) ) {
                        return ( string ) $str;
                }

                if ( !Helper::isNonEmptyStr( $str ) ) {
                        return "";
                }

                return \sanitize_key( $str );
        }

        
        public static function sanitizeiKey( $str = "" ) {

                if ( is_array( $str ) ) {
                        return array_map( [ __CLASS__, "sanitizeiKey" ], $str );
                }

                if ( !Helper::isNonEmptyStr( $str ) ) {
                        return "";
                }

                return preg_replace( '/[^a-zA-Z0-9_\-]/', '', $str );
        }

        
        public static function sanitizeText( $str = "" ) {

                if ( is_array( $str ) ) {
                        return array_map( [ __CLASS__, "sanitizeText" ], $str );
                }

                if ( !is_string( $str ) ) {
                        return $str;
                }

                if ( !Helper::isNonEmptyStr( $str ) ) {
                        return "";
                }

                return \sanitize_text_field( $str );
        }

        
        public static function sanitizeFilename( $name = "", $ext = "" ) {

                if ( !Helper::isNonEmptyStr( $name ) ) {
                        return "";
                }

                if ( $name === self::sanitizeiKey( $name ) || preg_match( '/^[a-zA-Z0-9_\-]+\.[a-zA-Z0-9]+$/', $name ) ) {
                        $newName = pathinfo( $name, PATHINFO_FILENAME ) ;
                } else {
                        $newName = \sanitize_file_name( pathinfo( $name, PATHINFO_FILENAME ) );
                }

                if ( !Helper::isNonEmptyStr( $ext ) ) {
                        $ext = Helper::getFileExt( $name );
                }

                if ( Helper::isNonEmptyStr( $ext ) ) {

                        $ext = "." . Helper::strTrim( self::sanitizeKey( $ext ), "." );

                        $newName = Helper::rightTrim( $newName, $ext ) . $ext;
                }

                return $newName;
        }

}
