<?php

namespace WpieApp\Core\Office\Converter\Excel;

use WP_Error;
use WpieApp\Core\Admin\AutoLoader;
use WpieApp\Core\Helpers\Helper;
use PhpOffice\PhpSpreadsheet\IOFactory;

defined( 'ABSPATH' ) || exit;

class Excel {

        
        public static function convert( $file = "", $dest = "", $options = [] ) {

                if ( !is_readable( $file ) ) {
                        /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( "Fail to open File %s", 'wp-import-export' ), $file ) );
                }

                $format = Helper::getFileExt( $dest );

                if ( !Helper::isNonEmptyStr( $format ) || !in_array( $format, [ "xls", "xlsx", "ods", "csv" ] ) ) {
                        return new WP_Error( 'wpieError', __( "Invalid File to convert Excel", 'wp-import-export' ) );
                }


                if ( isset( $options[ 'retry' ] ) && Helper::toInt( $options[ 'retry' ] ) > 0 ) {

                        if ( $format === "xls" ) {
                                return [ "status" => "fail" ];
                        }
                        if ( $format === "csv" ) {
                                return Excel2Csv::convert( $file, $dest, $options );
                        }

                        //return Excel2::convert( $file, $dest, $options );
                }
                
                AutoLoader::loadSpreadsheet();

                try {

                        if ( version_compare( phpversion(), WPIE_VENDOR_PHP_VERSION, '<' ) ) {
                                $reader = IOFactory::createReaderForFile( $file );
                        } else {

                                $fileFormat = Helper::getFileExt( $file );

                                $readerFormat = Helper::contains( $fileFormat, 'csv' ) ? [ 'Csv' ] : [ ucfirst( $fileFormat ) ];

                                $reader = IOFactory::createReaderForFile( $file, $readerFormat );
                        }

                        $reader->setReadDataOnly( true );

                        $reader->setReadEmptyCells( false );

                        if ( isset( $options[ 'sheet' ] ) && Helper::isNonEmptyStr( $options[ 'sheet' ] ) ) {
                                $reader->setLoadSheetsOnly( [ $options[ 'sheet' ] ] );
                        }

                        $spreadsheet = $reader->load( $file );

                        $writer = IOFactory::createWriter( $spreadsheet, ucfirst( $format ) );

                        if ( $format === "csv" ) {
                                $writer->setUseBOM( true );
                        }
                        $writer->save( $dest );

//			$writer = IOFactory::createWriter( $spreadsheet, ucfirst( $format ) );

                        $spreadsheet->disconnectWorksheets();

                        unset( $writer, $spreadsheet, $reader );
                } catch ( Exception $e ) {
                        return new WP_Error( 'wpieError', $e->getMessage() );
                }

                return [ "status" => "completed" ];
        }
}
