<?php


namespace WpieApp\Core\Page\Blocks\Fields;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Page\Blocks\Fields\Alert;

defined( 'WPIE__FILE__' ) || exit;


class ExportLog {

        
        const TYPE = "export-log";

        
        public static function render( $field ) {

                $templates = DB::wpdb()->get_results( "SELECT `id`,`total`,`log`,`content_type`,`category`,`process_type`,`options`,`status`,`file`,`created_date`,`updated_date` FROM " . DB::getPluginTable() . " where `process` = 'export' AND `process_type` IN ('regular','background') AND `status` NOT IN ('draft','init') ORDER BY `id` DESC", ARRAY_A );

                $emptyClass = Helper::isNonEmptyArray( $templates ) ? "d-none" : "";
                ?>
                <div class="wpie-log-wrapper">
                        <div class="wpie-log-empty-wrapper bg-light <?php echo esc_attr( $emptyClass ); ?>">
                                <div class="text-center m-auto py-4 bse-fw-600 bse-text-18"><?php esc_html_e( 'No records found', 'wp-import-export' ); ?></div>
                        </div>

                        <?php
                        if ( Helper::isNonEmptyArray( $templates ) ) {
                                self::renderData( $templates );
                        }
                        ?>
                </div>

                <?php
        }

        
        private static function renderData( $templates ) {

                $bgUid = Helper::randStr( "wpie-modal-" );
                ?>
                <div class="col-12 wpie-log-alert">
                        <?php
                        Alert::render(
                                [
                                        "type"       => "danger",
                                        "icon-class" => "fa-solid fa-triangle-exclamation",
                                        "class"      => "mb-4",
                                        "text"       => __( 'Only exports running in the background can be paused, resumed or stopped', 'wp-import-export' )
                                ]
                        );
                        ?>
                </div>
                <div class="wpie-export-log-wrapper wpie-log-container bg-white container bse-fs-12">
                        <div class="row py-4 border rounded-3 bg-primary bg-opacity-10 p-3">
                                <div class="col my-auto">
                                        <div class="wpie-field">
                                                <select class="form-control form-select wpie-select wpie-bulk-actions" data-minimum-results-for-search="Infinity" data-placeholder="<?php esc_html_e( 'Bulk Actions', 'wp-import-export' ); ?>" >
                                                        <option></option>
                                                        <option value="remove"><?php esc_html_e( 'Remove', 'wp-import-export' ); ?></option>
                                                        <option value="paused"><?php esc_html_e( 'Pause', 'wp-import-export' ); ?></option>
                                                        <option value="resume"><?php esc_html_e( 'Resume', 'wp-import-export' ); ?></option>
                                                        <option value="stopped"><?php esc_html_e( 'Stop', 'wp-import-export' ); ?></option>
                                                        <option value="background"><?php esc_html_e( 'Set Background Processing', 'wp-import-export' ); ?></option>
                                                </select>
                                        </div>
                                </div>
                                <div class="col-auto my-auto">
                                        <div class="wpie-field">
                                                <button type="button" class="btn wpie-bulk-action-btn btn-primary"><i class="bse-fs-14 me-1 fa-solid fa-check"></i><?php esc_html_e( 'Apply', 'wp-import-export' ); ?></button>
                                        </div>
                                </div>
                        </div>
                        <div class="row py-4 border rounded-3 bg-primary bg-opacity-10 p-3 mt-3">
                                <div class="col my-auto">
                                        <div class="wpie-field">
                                                <select class="form-control form-select wpie-select wpie-log-filter" data-minimum-results-for-search="Infinity" data-placeholder="<?php esc_html_e( 'Filter Entries', 'wp-import-export' ); ?>" >
                                                        <option></option>
                                                        <option value="all"><?php esc_html_e( 'All Logs', 'wp-import-export' ); ?></option>
                                                        <option value="processing"><?php esc_html_e( 'Processing', 'wp-import-export' ); ?></option>
                                                        <option value="paused"><?php esc_html_e( 'Paused', 'wp-import-export' ); ?></option>
                                                        <option value="completed"><?php esc_html_e( 'Completed', 'wp-import-export' ); ?></option>
                                                        <option value="failed"><?php esc_html_e( 'Failed', 'wp-import-export' ); ?></option>
                                                        <option value="stopped"><?php esc_html_e( 'Stopped', 'wp-import-export' ); ?></option>
                                                        <option value="background"><?php esc_html_e( 'Background Processing', 'wp-import-export' ); ?></option>
                                                </select>
                                        </div>
                                </div>

                        </div>
                        <div class="row py-4 border rounded-3 bg-primary wpie-filter-empty-record bg-opacity-10 p-3 mt-3 d-none">
                                <div class="col my-auto">
                                        <div class="wpie-field">
                                                <div class="wpie-log-wrapper">
                                                        <div class=" bg-light ">
                                                                <div class="text-center m-auto py-4 bse-fw-600 bse-text-18"><?php esc_html_e( 'No records found', 'wp-import-export' ); ?></div>
                                                        </div>

                                                </div>
                                        </div>
                                </div>

                        </div>
                        <div class="row py-4 bse-fw-600 wpie-log-records-container">
                                <div class="col-auto m-auto">
                                        <div class="form-check ">
                                                <input type="checkbox" class="form-check-input form-checkbox wpie-check-all" value="" />
                                        </div>
                                </div>
                                <div class="col m-auto"><?php esc_html_e( 'File', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Content Type', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Date', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Summary', 'wp-import-export' ); ?></div>
                        </div>
                        <?php
                        foreach ( $templates as $data ) {

                                $id                 = isset( $data[ 'id' ] ) ? $data[ 'id' ] : "";
                                $file               = isset( $data[ 'file' ] ) ? $data[ 'file' ] : "";
                                $date               = isset( $data[ 'created_date' ] ) ? Date::getLocal( $data[ 'created_date' ] ) : "";
                                $updatedDate        = isset( $data[ 'updated_date' ] ) ? Date::getLocal( $data[ 'updated_date' ] ) : "";
                                $category           = isset( $data[ 'category' ] ) ? $data[ 'category' ] : "";
                                $contentType        = isset( $data[ 'content_type' ] ) ? $data[ 'content_type' ] : "";
                                $status             = isset( $data[ 'status' ] ) ? $data[ 'status' ] : "";
                                $processType        = isset( $data[ 'process_type' ] ) ? $data[ 'process_type' ] : "";
                                $total              = isset( $data[ 'total' ] ) ? $data[ 'total' ] : "";
                                $log                = isset( $data[ 'log' ] ) && Helper::isNonEmptyStr( $data[ 'log' ] ) ? maybe_unserialize( $data[ 'log' ] ) : [];
                                $processed          = isset( $log[ 'processed' ] ) ? $log[ 'processed' ] : 0;
                                $statusClass        = ImportLog::getStatusClass( $status );
                                $options            = isset( $data[ 'options' ] ) && Helper::isNonEmptyStr( $data[ 'options' ] ) ? \maybe_unserialize( $data[ 'options' ] ) : [];
                                $scheduleName       = isset( $options[ 'scheduleName' . $id ] ) ? $options[ 'scheduleName' . $id ] : '';
                                $scheduleRecurrence = isset( $options[ 'scheduleRecurrence' . $id ] ) ? $options[ 'scheduleRecurrence' . $id ] : '';
                                $error              = "";
                                if ( $status === "failed" ) {
                                        $error = isset( $options[ 'error' ] ) ? $options[ 'error' ] : "";
                                }

                                $bgClass = ('background' === $processType) && !in_array( $status, [ 'completed', 'cancelled', 'failed', 'stopped' ] ) ? 'wpie-log-background' : '';

                                $contentTypeLabel = (isset( $options[ 'info' ] ) && isset( $options[ 'info' ][ 'contentTypeLabel' ] ) ? $options[ 'info' ][ 'contentTypeLabel' ] : '');
                                ?>
                                <div class="row border-top py-4 wpie-log wpie-log-<?php echo esc_attr( $id ) ?> wpie-log-<?php echo esc_attr( $status ) ?> <?php echo esc_attr( $bgClass ) ?>" log-id="<?php echo esc_attr( $id ) ?>">
                                        <div class="col-auto m-auto">
                                                <div class="form-check ">
                                                        <input type="checkbox" class="form-check-input form-checkbox wpie-check wpie-export-log-ids" value="<?php echo esc_attr( $id ) ?>" />
                                                </div>
                                        </div>
                                        <div class="col m-auto">
                                                <?php if ( Helper::isNonEmptyStr( $scheduleName ) ) { ?>
                                                        <div class=""><?php esc_html_e( 'Schedule', 'wp-import-export' ); ?></div>                                                        
                                                        <div class="text-primary bse-fw-600"><?php echo esc_html( $scheduleName ); ?></div> 
                                                        <?php if ( is_numeric( $scheduleRecurrence ) && absint( $scheduleRecurrence ) > 0 ) { ?>
                                                                <div><?php esc_html_e( 'Recurrence:', 'wp-import-export' ); ?> <strong class="text-dark"><?php echo esc_html( $scheduleRecurrence ); ?></strong></div> 
                                                        <?php } ?>
                                                <?php } ?>
                                                <div class="mt-3"><?php echo esc_html( Helper::isNonEmptyStr( $file ) ? $file : '---' ); ?></div>
                                                <div class="bse-fs-20 mt-3">
                                                        <i class="fa-solid fa-trash text-danger me-3 bse-cursor-pointer wpie-process-action-btn wpie-remove-log-btn" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Remove Record', 'wp-import-export' ); ?>"></i>
                                                        <?php if ( !in_array( $status, [ 'completed', 'cancelled', 'failed', 'stopped', 'pre-completed' ] ) ) { ?>
                                                                <i class="fa-solid fa-arrows-spin me-3 text-success bse-cursor-pointer wpie-process-action-btn wpie-background-process-btn <?php echo ('background' === $processType) ? esc_attr( 'd-none' ) : ''; ?>" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'set export in background', 'wp-import-export' ); ?>"></i>
                                                        <?php } ?>
                                                        <?php if ( $total > 0 ) { ?>
                                                                <i class="fa-solid fa-file me-3 text-primary bse-cursor-pointer wpie-download-process-file wpie-download-export-file" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Download File', 'wp-import-export' ); ?>"></i>
                                                        <?php } ?>
                                                        <?php if ( 'completed' === $status ) { ?>
                                                                <i class="fa-solid fa-file-zipper me-3 text-primary bse-cursor-pointer wpie-download-export-bundle" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Download bundle', 'wp-import-export' ); ?>"></i>
                                                        <?php } ?>
                                                        <i class="fa-solid fa-circle-play me-3 text-success bse-cursor-pointer wpie-process-action-btn wpie-resume-process-btn <?php
                                                        if ( $status !== "paused" || 'background' !== $processType ) {
                                                                echo esc_attr( 'd-none' );
                                                        }
                                                        ?>" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Resume Export', 'wp-import-export' ); ?>"></i>
                                                        <i class="fa-solid fa-circle-pause me-3 text-primary bse-cursor-pointer wpie-process-action-btn wpie-pause-process-btn <?php
                                                        if ( !in_array( $status, [ 'processing', 'waiting' ] ) || 'background' !== $processType ) {
                                                                echo esc_attr( 'd-none' );
                                                        }
                                                        ?>" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Pause Export', 'wp-import-export' ); ?>"></i>
                                                        <i class="fa-solid fa-circle-stop me-3 text-danger bse-cursor-pointer wpie-process-action-btn wpie-stop-process-btn <?php
                                                        if ( in_array( $status, [ 'completed', 'cancelled', 'failed', 'stopped', 'pre-completed' ] ) ) {
                                                                echo esc_attr( 'd-none' );
                                                        }
                                                        ?>" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Stop Export', 'wp-import-export' ); ?>"></i>

                                                </div>
                                        </div>
                                        <div class="col m-auto">
                                                <?php if ( Helper::isNonEmptyStr( $contentTypeLabel ) ) { ?>
                                                        <div class="text-primary bse-fw-600"><?php echo esc_html( $contentTypeLabel ); ?></div> 
                                                <?php } ?>
                                                <div class="text-success"><?php echo esc_html( $category . " => " . $contentType ); ?></div>
                                        </div>
                                        <div class="col m-auto">
                                                <div><?php esc_html_e( 'Start', 'wp-import-export' ); ?></div>
                                                <div class="text-success"><?php echo esc_html( $date ); ?></div>
                                                <div class="mt-3"><?php esc_html_e( 'Last Run', 'wp-import-export' ); ?></div>
                                                <div class="text-success"><?php echo esc_html( $updatedDate ); ?></div>
                                        </div>
                                        <div class="col m-auto">
                                                <div><?php esc_html_e( 'Status', 'wp-import-export' ); ?> : <strong class="wpie-log-status <?php echo esc_attr( $statusClass ) ?>"><?php echo \esc_html( ImportLog::getStatusText( $status ) ); ?></strong></div>                                               
                                                <?php if ( !in_array( $status, [ 'completed', 'cancelled', 'failed', 'stopped' ] ) ) { ?>
                                                        <div class="wpie-log-status-background-text <?php echo ('background' === $processType) ? '' : esc_attr( 'd-none' ); ?>"><?php esc_html_e( 'Processing', 'wp-import-export' ); ?> : <strong class="text-primary"><?php esc_html_e( 'In background', 'wp-import-export' ); ?> </strong></div>
                                                <?php } ?>
                                                <div><?php esc_html_e( 'Total', 'wp-import-export' ); ?> : <strong><?php echo esc_html( $total ); ?></strong></div>
                                                <div><?php esc_html_e( 'Processed', 'wp-import-export' ); ?> : <strong><?php echo esc_html( $processed ); ?></strong></div>
                                        </div>
                                        <?php if ( Helper::isNonEmptyStr( $error ) ) { ?>
                                                <div class="col-12 mt-3 text-danger bse-fs-12 mb-3"><span class="bse-fw-600 bse-fs-14"><?php esc_html_e( 'Error', 'wp-import-export' ); ?> : </span><?php echo esc_html( $error ); ?></div>
                                        <?php } ?>
                                </div>
                                <?php
                        }
                        ?>

                </div>


                <?php
        }
}
