<?php


namespace WpieApp\Core\Page\Blocks\Fields;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class ManageSettings {

        
        const TYPE = "manage-settings";

        
        public static function render( $field ) {

                $templates = DB::wpdb()->get_results( "SELECT `id`,`name`,`process`,`content_type`,`category`,`created_date` FROM " . DB::getPluginTable() . " where `process_type` = 'setting' AND `name` !='' ORDER BY `id` DESC", ARRAY_A );

                $emptyClass = Helper::isNonEmptyArray( $templates ) ? "d-none" : "";
                ?>
                <div class="wpie-log-wrapper">
                        <div class="wpie-log-empty-wrapper bg-light <?php echo esc_attr( $emptyClass ); ?>">
                                <div class="text-center m-auto py-4 bse-fw-600 bse-text-18"><?php esc_html_e( 'No records found', 'wp-import-export' ); ?></div>
                        </div>

                        <?php
                        if ( Helper::isNonEmptyArray( $templates ) ) {
                                self::renderData( $templates );
                        }
                        ?>
                </div>

                <?php
        }

        
        private static function renderData( $templates ) {
                ?>
                <div class="wpie-export-log-wrapper wpie-log-container bg-white container bse-fs-12">
                        <div class="row py-4">
                                <div class="col-auto my-auto">
                                        <div class="wpie-field">
                                                <select class="form-control form-select wpie-select wpie-bulk-actions" data-minimum-results-for-search="Infinity" data-placeholder="<?php esc_html_e( 'Bulk Actions', 'wp-import-export' ); ?>" >
                                                        <option></option>
                                                        <option value="remove"><?php esc_html_e( 'Remove Selected', 'wp-import-export' ); ?></option>
                                                        <option value="download"><?php esc_html_e( 'Download Selected Settings', 'wp-import-export' ); ?></option>
                                                </select>
                                        </div>
                                </div>
                                <div class="col-auto my-auto">
                                        <div class="wpie-field">
                                                <button type="button" class="btn wpie-bulk-action-btn btn-primary"><i class="bse-fs-14 me-1 fa-solid fa-check"></i><?php esc_html_e( 'Apply', 'wp-import-export' ); ?></button>
                                        </div>
                                </div>
                        </div>
                        <div class="row py-4 bse-fw-600">
                                <div class="col-auto m-auto">
                                        <div class="form-check ">
                                                <input type="checkbox" class="form-check-input form-checkbox wpie-check-all" value="" />
                                        </div>
                                </div>
                                <div class="col m-auto"><?php esc_html_e( 'Name', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Process', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Content Type', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Date', 'wp-import-export' ); ?></div>
                                <div class="col m-auto "><?php esc_html_e( 'Actions', 'wp-import-export' ); ?></div>

                        </div>
                        <?php
                        foreach ( $templates as $data ) {

                                $name = isset( $data[ 'name' ] ) ? $data[ 'name' ] : "";

                                if ( !Helper::isNonEmptyStr( $name ) ) {
                                        continue;
                                }

                                $id = isset( $data[ 'id' ] ) ? $data[ 'id' ] : "";

                                $process     = isset( $data[ 'process' ] ) ? $data[ 'process' ] : "";
                                $date        = isset( $data[ 'created_date' ] ) ? $data[ 'created_date' ] : "";
                                $category    = isset( $data[ 'category' ] ) ? $data[ 'category' ] : "";
                                $contentType = isset( $data[ 'content_type' ] ) ? $data[ 'content_type' ] : "";
                                ?>
                                <div class="row border-top py-4" log-id="<?php echo esc_attr( $id ) ?>">
                                        <div class="col-auto m-auto">
                                                <div class="form-check ">
                                                        <input type="checkbox" class="form-check-input form-checkbox wpie-check wpie-settings-ids" value="<?php echo esc_attr( $id ) ?>" />
                                                </div>
                                        </div>
                                        <div class="col m-auto">
                                                <?php echo esc_html( $name ); ?>

                                        </div>
                                        <div class="col m-auto"><?php echo esc_html( $process ); ?></div>
                                        <div class="col m-auto"><?php echo esc_html( $category . " => " . $contentType ); ?></div>
                                        <div class="col m-auto"><?php echo esc_html( $date ); ?></div>
                                        <div class="col m-auto bse-fs-24">
                                                <i class="fa-solid fa-trash text-danger me-3 bse-cursor-pointer wpie-remove-setting-btn" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Remove Setting', 'wp-import-export' ); ?>"></i>
                                                <i class="fa-solid fa-file-lines me-3 text-primary bse-cursor-pointer wpie-download-setting-btn" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Download Setting File', 'wp-import-export' ); ?>"></i>
                                        </div>
                                </div>
                                <?php
                        }
                        ?>

                </div>

                <?php
        }

}
