<?php


namespace WpieApp\Core\Page\Blocks\Fields;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Page\Blocks\Fields;

defined( 'WPIE__FILE__' ) || exit;


class Radio {

        
        const TYPE = "radio";

        
        const ATTR = [ 'class', 'name', 'readonly', 'disabled', 'required' ];

        
        public static function render( $field ) {

                $html = "";

                $choices = isset( $field[ "choices" ] ) && Helper::isNonEmptyArray( $field[ "choices" ] ) ? $field[ "choices" ] : [];

                if ( !Helper::isNonEmptyArray( $choices ) ) {
                        return "";
                }
                $hints   = isset( $field[ "hints" ] ) && Helper::isNonEmptyArray( $field[ "hints" ] ) ? $field[ "hints" ] : [];
                $preHtml = isset( $field[ "preHtml" ] ) && Helper::isNonEmptyArray( $field[ "preHtml" ] ) ? $field[ "preHtml" ] : [];

                $field[ "class" ] = "form-check-input form-radio " . (isset( $field[ "class" ] ) ? $field[ "class" ] : "");

                foreach ( self::ATTR as $attr ) {

                        if ( !isset( $field[ $attr ] ) ) {
                                continue;
                        }

                        $field[ $attr ] = Helper::toString( $field[ $attr ] );

                        $html .= sprintf( ' %1$s="%2$s"', esc_attr( trim( $attr ) ), esc_attr( trim( $field[ $attr ] ) ) );
                }

                $default = isset( $field[ "default" ] ) && Helper::isNonEmptyStr( $field[ "default" ] ) ? $field[ "default" ] : "";

                $inline       = isset( $field[ "inline" ] ) && $field[ "inline" ] === true ? " form-check-inline" : "";
                $switchClass  = isset( $field[ "is-switch" ] ) && $field[ "is-switch" ] === true ? " form-switch" : "";
                $fieldClass   = isset( $field[ "field-class" ] ) && Helper::isNonEmptyStr( $field[ "field-class" ] ) ? " " . Helper::sanitizeText( $field[ "field-class" ] ) : "";
                $choicesClass = isset( $field[ "choices-class" ] ) && Helper::isNonEmptyArray( $field[ "choices-class" ] ) ? $field[ "choices-class" ] : "";

                foreach ( $choices as $val => $label ) {

                        $preHtmlLabel = isset( $preHtml[ $val ] ) ? $preHtml[ $val ] : "";

                        $parentClass = isset( $choicesClass[ $val ] ) && Helper::isNonEmptyStr( $choicesClass[ $val ] ) ? " " . Helper::sanitizeText( $choicesClass[ $val ] ) : "";
                        $id          = Helper::randStr( "wpie-radio-" );
                        ?>
                        <div class="form-check <?php echo \esc_attr( trim( $inline . $switchClass . $fieldClass . $parentClass ) ); ?>">
                                <?php //$html is already escaped in loop ?>
                                <?php //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                                <input type="radio" <?php echo $html; ?> id="<?php echo \esc_attr( trim( $id ) ); ?>" value="<?php echo \esc_attr( trim( Helper::toString( $val ) ) ); ?>" <?php \checked( $val, $default ); ?> >
                                <label class="form-check-label ps-1" for="<?php echo esc_attr( trim( $id ) ); ?>"><?php echo \wp_kses( $preHtmlLabel, [] ); ?><?php echo \esc_html( trim( Helper::toString( $label ) ) ); ?></label>
                                <?php if ( isset( $hints[ $val ] ) && Helper::isNonEmptyStr( $hints[ $val ] ) ) { ?>
                                        <div class="form-check-hint ps-1 bse-fs-12 text-success pb-2" ><?php echo \esc_html( trim( Helper::toString( $hints[ $val ] ) ) ); ?></div>
                                        <?php
                                }
                                if ( isset( $field[ "fields" ] ) && isset( $field[ "fields" ][ $val ] ) ) {

                                        Fields::renderChild( $field[ "fields" ] [ $val ] );
                                }
                                ?>

                        </div>
                        <?php
                }
        }
}
