<?php



namespace WpieApp\Core\Utils\Archive;

use WP_Error;
use ZipArchive;
use WpieApp\Core\Helpers\Helper;


class ZipHandler extends Base {

        
        public static function open( $file, $flags = 0, $create = false ) {

                if ( !class_exists( '\ZipArchive' ) ) {
                        return new WP_Error( 'missing_extension', __( 'The ZIP extension is not available on this server.', 'wp-import-export' ) );
                }

                if ( !$create && !file_exists( $file ) ) {
                        return new WP_Error( 'file_not_found', __( 'The specified file does not exist.', 'wp-import-export' ) );
                }

                $zip    = new ZipArchive();
                $result = $zip->open( $file, $flags );

                if ( $result === true ) {
                        return $zip;
                }

                return new WP_Error( 'zip_error', __( 'Failed to open the ZIP file.', 'wp-import-export' ) );
        }

        
        public static function canOpen() {

                return \class_exists( '\ZipArchive' );
        }

        
        public static function extract( $file = "", $filename = "", $options = [] ) {

                $archive = self::open( $file );

                if ( \is_wp_error( $archive ) ) {
                        return $archive;
                }

                $outputFolder = isset( $options[ 'outputFolder' ] ) && Helper::isNonEmptyStr( $options[ 'outputFolder' ] ) ? $options[ 'outputFolder' ] : '';

                //Extract File
                try {
                        $name = $filename;

                        $archive->extractTo( $outputFolder, $name );

                        $archive->close();
                } catch ( Exception $e ) {

                        return new WP_Error( 'wpieError', $e->getMessage() );
                }

                //Check if Extract in sub Foders
                $extractFile = Helper::pathJoin( $outputFolder, $filename );
                $filePath    = Helper::pathJoin( $outputFolder, basename( $filename ) );
                if ( $filePath !== $extractFile ) {

                        Helper::getFilesystem()->move( $extractFile, $filePath );

                        self::removeExtraFolders( $filename, $outputFolder );
                }

                return $filePath;
        }

        
        public static function create( $zipFile, $files ) {

                if ( !Helper::isNonEmptyArray( $files ) ) {
                        return new WP_Error( 'ZipError', __( 'File list is empty; ZIP creation failed.', 'wp-import-export' ) );
                }

                $zip = self::open( $zipFile, ZipArchive::CREATE, true );

                if ( \is_wp_error( $zip ) ) {
                        return $zip;
                }

                foreach ( $files as $file ) {
                        if ( !file_exists( $file ) ) {
                                $zip->close();
                                return new WP_Error( 'file_not_found', sprintf( __( 'File not found: %s', 'wp-import-export' ), $file ) );
                        }

                        $zip->addFile( $file, basename( $file ) );
                }
                $zip->close();
                return true;
        }

        
        public static function getFileList( $file = "", $options = [] ) {

                $zip = self::open( $file );

                if ( \is_wp_error( $zip ) ) {
                        return $zip;
                }
                $allowedExt = isset( $options[ 'allowedExt' ] ) && Helper::isNonEmptyArray( $options[ 'allowedExt' ] ) ? $options[ 'allowedExt' ] : [];

                $fileList = [];

                for ( $i = 0; $i < $zip->numFiles; $i++ ) {

                        $filename = $zip->getNameIndex( $i );

                        $ext = Helper::getFileExt( $filename );

                        if ( !Helper::isNonEmptyArray( $allowedExt ) || !in_array( $ext, $allowedExt ) ) {
                                continue;
                        }

                        $fileList[] = $filename;
                }

                $zip->close();
                return $fileList;
        }
}
