<?php



namespace WpieApp\Core\Utils;

use WP_Error;
use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;

class FileUploadManager {

        
        public static function handleUpload( $fileInputName = '', $destinationPath = '' ) {

                $tempName = self::validate( $fileInputName );

                if ( \is_wp_error( $tempName ) ) {
                        return $tempName;
                }

                // Use WordPress Filesystem API to handle file upload
                if ( !Helper::getFilesystem()->move( $tempName, $destinationPath, true ) ) {
                        return new WP_Error( 'upload_failed', __( 'File upload failed.', 'wp-import-export' ) );
                }

                return true;
        }

        
        public static function read( $fileInputName = '' ) {

                $tempName = self::validate( $fileInputName );

                if ( \is_wp_error( $tempName ) ) {
                        return $tempName;
                }

                return Helper::getFilesystem()->get_contents( $tempName );
        }

        
        private static function validate( $fileInputName = '' ) {

                // Uploaded files will undergo validation within this function
                // phpcs:ignore 
                if ( !isset( $_FILES[ $fileInputName ] ) ) {
                        return new WP_Error( 'no_file', __( 'No file uploaded.', 'wp-import-export' ) );
                }
                
                // Uploaded files will undergo validation within this function
                // phpcs:ignore 
                $file = $_FILES[ $fileInputName ];

                // Validate necessary fields in the uploaded file array
                if ( !isset( $file[ 'tmp_name' ] ) || !isset( $file[ 'name' ] ) || !isset( $file[ 'error' ] ) ) {
                        return new WP_Error( 'invalid_file_data', __( 'Invalid file upload data.', 'wp-import-export' ) );
                }

                // Check for upload errors
                if ( $file[ 'error' ] !== UPLOAD_ERR_OK ) {
                        return self::getFileUploadError( $file[ 'error' ] );
                }
                // Check for upload errors
                if ( !Helper::getFilesystem()->exists( $file[ 'tmp_name' ] ) ) {
                        return new WP_Error( 'no_file', __( 'The file does not exist', 'wp-import-export' ) );
                }

                return $file[ 'tmp_name' ];
        }

        
        private static function getFileUploadError( $errorCode ) {
                switch ( $errorCode ) {
                        case UPLOAD_ERR_INI_SIZE:
                        case UPLOAD_ERR_FORM_SIZE:
                                return new WP_Error( 'file_size_exceeded', __( 'The uploaded file exceeds the allowed size limit.', 'wp-import-export' ) );
                        case UPLOAD_ERR_PARTIAL:
                                return new WP_Error( 'partial_upload', __( 'The file was only partially uploaded.', 'wp-import-export' ) );
                        case UPLOAD_ERR_NO_FILE:
                                return new WP_Error( 'no_file_uploaded', __( 'No file was uploaded.', 'wp-import-export' ) );
                        case UPLOAD_ERR_NO_TMP_DIR:
                                return new WP_Error( 'no_temp_dir', __( 'Missing a temporary folder.', 'wp-import-export' ) );
                        case UPLOAD_ERR_CANT_WRITE:
                                return new WP_Error( 'cant_write', __( 'Failed to write file to disk.', 'wp-import-export' ) );
                        case UPLOAD_ERR_EXTENSION:
                                return new WP_Error( 'upload_stopped', __( 'A PHP extension stopped the file upload.', 'wp-import-export' ) );
                        default:
                                return new WP_Error( 'unknown_error', __( 'An unknown error occurred during file upload.', 'wp-import-export' ) );
                }
        }
}
