<?php



namespace WpieApp\Core\Utils;

use WP_Error;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Upgrade\Core;

defined( 'WPIE__FILE__' ) || exit;


class License {

        
        const CIPHER = "aes-256-cbc";

        
        public static function isActive() {

                return false !== self::getData();
        }

        
        public static function getData() {

                $data = \get_option( self::getDBKey() );

                if ( !$data ) {
                        return false;
                }

                $licenseData = self::decryptData( $data );

                if ( !is_array( $licenseData ) || !isset( $licenseData[ 'license' ] ) ) {
                        return false;
                }

                return $licenseData;
        }

        
        public static function get() {

                $license = self::getData();

                if ( false === $license ) {
                        return false;
                }

                return isset( $license[ 'license' ] ) ? $license[ 'license' ] : '';
        }

        
        public static function encryptData( $data ) {

                $data = Helper::isNonEmptyArray( $data ) ? maybe_serialize( $data ) : $data;

                $ivLength = \openssl_cipher_iv_length( self::CIPHER );

                $iv = \openssl_random_pseudo_bytes( $ivLength );

                $encryptedData = \openssl_encrypt( $data, self::CIPHER, self::getDBKey(), OPENSSL_RAW_DATA, $iv );

                return \base64_encode( $iv . $encryptedData );
        }

        
        public static function decryptData( $encryptedData ) {

                $encryptedData = \base64_decode( $encryptedData );

                $ivLength = \openssl_cipher_iv_length( self::CIPHER );

                $iv = substr( $encryptedData, 0, $ivLength );

                $encryptedData = substr( $encryptedData, $ivLength );

                $decryptedData = \openssl_decrypt( $encryptedData, self::CIPHER, self::getDBKey(), OPENSSL_RAW_DATA, $iv );

                return \maybe_unserialize( $decryptedData );
        }

        
        public static function getDBKey() {
                return \hash( 'sha256', 'wpie-license' );
        }

        
        public static function getDomainFromURL( $url ) {

                // Remove the scheme (e.g., http:// or https://)
                $url = \preg_replace( '#^https?://#', '', $url );

                // Remove any path or query string
                $url = \preg_replace( '/\/(.+)?/', '', $url );

                // Split the URL by dots
                $parts = \explode( '.', $url );

                // Get the last two parts (domain and TLD)
                $domain = $parts[ count( $parts ) - 2 ] . '.' . $parts[ count( $parts ) - 1 ];

                return $domain;
        }

        
        public static function update( $data = [] ) {

                \update_option( self::getDBKey(), self::encryptData( $data ) );

                Core::refreshTransient();
        }

        
        public static function remove() {

                \delete_option( self::getDBKey() );

                Core::refreshTransient();
        }
}
