<?php



namespace WpieApp\Extensions\Export\RankMathSeo\Controller\Items\Base\Fields;

use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;

defined( 'WPIE__FILE__' ) || exit;


class Seo implements InterfaceField {

        
        protected static $metaType = "";

        
        const FIELD_TYPE = "rankmath-seo";

        
        public static function get() {

                $fields = [
                        "title"      => \esc_html__( "RankMath SEO", 'wp-import-export' ),
                        "priority"   => 28,
                        "isFiltered" => false,
                        "pro"        => true,
                        "data"       => static::getFields()
                ];

                
                return \apply_filters( 'Wpie/Export/Post/Fields/RankMathSeo', $fields, Settings::getContentType() );
        }

        
        protected static function getFields() {

                return array_merge(
                        static::getGeneralFields(),
                        static::getSocialFields(),
                        static::getAdvancedFields(),
                        static::getSchemaFields()
                );
        }

        
        protected static function getGeneralFields() {

                return [
                        //General
                        [ 'label' => 'SEO Title', 'type' => static::$metaType, 'element' => 'rank_math_title' ],
                        [ 'label' => 'SEO Description', 'type' => static::$metaType, 'element' => 'rank_math_description' ],
                        [ 'label' => 'SEO Focus Keyword', 'type' => static::$metaType, 'element' => 'rank_math_focus_keyword' ],
                        [ 'label' => 'SEO Score', 'type' => static::$metaType, 'element' => 'rank_math_seo_score' ],
                ];
        }

        
        protected static function getSocialFields() {

                return [
                        //Facebook
                        [ 'label' => 'SEO Facebook Title', 'type' => static::$metaType, 'element' => 'rank_math_facebook_title' ],
                        [ 'label' => 'SEO Facebook Description', 'type' => static::$metaType, 'element' => 'rank_math_facebook_description' ],
                        [ 'label' => 'SEO Facebook Image', 'type' => static::$metaType, 'element' => 'rank_math_facebook_image' ],
                        [ 'label' => 'SEO Facebook Add icon overlay to thumbnail', 'type' => static::$metaType, 'element' => 'rank_math_facebook_enable_image_overlay' ],
                        [ 'label' => 'SEO Facebook Icon overlay', 'type' => static::$metaType, 'element' => 'rank_math_facebook_image_overlay' ],
                        //Twitter
                        [ 'label' => 'SEO Twitter Use Data from Facebook Tab', 'type' => static::$metaType, 'element' => 'rank_math_twitter_use_facebook' ],
                        [ 'label' => 'SEO Twitter Title', 'type' => static::$metaType, 'element' => 'rank_math_twitter_title' ],
                        [ 'label' => 'SEO Twitter Description', 'type' => static::$metaType, 'element' => 'rank_math_twitter_description' ],
                        [ 'label' => 'SEO Twitter Image', 'type' => static::$metaType, 'element' => 'rank_math_twitter_image' ],
                        [ 'label' => 'SEO Twitter Add icon overlay to thumbnail', 'type' => static::$metaType, 'element' => 'rank_math_twitter_enable_image_overlay' ],
                        [ 'label' => 'SEO Twitter Icon overlay', 'type' => static::$metaType, 'element' => 'rank_math_twitter_image_overlay' ],
                        //Card Type
                        [ 'label' => 'SEO Twitter Card Type', 'type' => static::$metaType, 'element' => 'rank_math_twitter_card_type' ],
                        //App Card
                        [ 'label' => 'SEO Twitter App Description', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_description' ],
                        [ 'label' => 'SEO Twitter App Iphone Name', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_iphone_name' ],
                        [ 'label' => 'SEO Twitter App Iphone ID', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_iphone_id' ],
                        [ 'label' => 'SEO Twitter App Iphone URL', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_iphone_url' ],
                        [ 'label' => 'SEO Twitter App Ipad Name', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_ipad_name' ],
                        [ 'label' => 'SEO Twitter App Ipad ID', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_ipad_id' ],
                        [ 'label' => 'SEO Twitter App Ipad URL', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_ipad_url' ],
                        [ 'label' => 'SEO Twitter App Googlepay Name', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_googleplay_name' ],
                        [ 'label' => 'SEO Twitter App Googlepay ID', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_googleplay_id' ],
                        [ 'label' => 'SEO Twitter App Googlepay URL', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_googleplay_url' ],
                        [ 'label' => 'SEO Twitter App Country', 'type' => static::$metaType, 'element' => 'rank_math_twitter_app_country' ],
                        //Player Card
                        [ 'label' => 'SEO Twitter Player URL', 'type' => static::$metaType, 'element' => 'rank_math_twitter_player_url' ],
                        [ 'label' => 'SEO Twitter Player Size', 'type' => static::$metaType, 'element' => 'rank_math_twitter_player_size' ],
                        [ 'label' => 'SEO Twitter Player Stream', 'type' => static::$metaType, 'element' => 'rank_math_twitter_player_stream' ],
                        [ 'label' => 'SEO Twitter Player Stream Content Type', 'type' => static::$metaType, 'element' => 'rank_math_twitter_player_stream_ctype' ],
                ];
        }

        
        protected static function getAdvancedFields() {


                $fields = [
                        // Robots Meta
                        [ 'label' => 'SEO Robots No Index', 'type' => self::FIELD_TYPE, 'element' => 'robots-noindex' ],
                        [ 'label' => 'SEO Robots No Follow', 'type' => self::FIELD_TYPE, 'element' => 'robots-nofollow' ],
                        [ 'label' => 'SEO Robots No Archive', 'type' => self::FIELD_TYPE, 'element' => 'robots-noarchive' ],
                        [ 'label' => 'SEO Robots No Image Index', 'type' => self::FIELD_TYPE, 'element' => 'robots-noimageindex' ],
                        [ 'label' => 'SEO Robots No Snippet', 'type' => self::FIELD_TYPE, 'element' => 'robots-nosnippet' ],
                        [ 'label' => 'SEO Robots Max Snippet', 'type' => self::FIELD_TYPE, 'element' => 'robots-max-snippet' ],
                        [ 'label' => 'SEO Robots Max Video Preview', 'type' => self::FIELD_TYPE, 'element' => 'robots-max-video-preview' ],
                        [ 'label' => 'SEO Robots Max Image Preview', 'type' => self::FIELD_TYPE, 'element' => 'robots-max-image-preview' ],
                        [ 'label' => 'SEO Canonical URL', 'type' => static::$metaType, 'element' => 'rank_math_canonical_url' ],
                        [ 'label' => 'SEO Redirect Status', 'type' => self::FIELD_TYPE, 'element' => 'redirect-status' ],
                        [ 'label' => 'SEO Redirection Type', 'type' => self::FIELD_TYPE, 'element' => 'redirect-header_code' ],
                        [ 'label' => 'SEO Destination URL', 'type' => self::FIELD_TYPE, 'element' => 'redirect-url_to' ],
                ];

                if ( function_exists( '\rank_math_the_breadcrumbs' ) ) {
                        $fields[] = [ 'label' => 'SEO Breadcrumb Title', 'type' => static::$metaType, 'element' => 'rank_math_breadcrumb_title' ];
                }

                return $fields;
        }

        
        protected static function getSchemaFields() {

                return [
                        // Schema
                        [ 'label' => 'SEO Schema', 'type' => self::FIELD_TYPE, 'element' => 'schema' ],
                ];
        }
}
