<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Filters;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Filter;
use WpieApp\Modules\Export\Controller\Items\Base\Filters\Filter as BaseFilter;
use WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Query\Order;

defined( 'WPIE__FILE__' ) || exit;


class Taxonomy extends BaseFilter {

        
        protected static $isJoinQueryAdded = false;

        
        public static function addRule() {

                $element = Filter::getOption( "element", "field" );

                if ( !Helper::isNonEmptyStr( $element ) ) {
                        return false;
                }

                static::addJoinQuery();

                $condition = Filter::getOption( 'condition' );

                if ( in_array( $condition, [ "not_equals", "not_contains", "not_in" ] ) ) {
                        static::addNotRule();
                        return;
                }

                static::add();
        }

        
        public static function add() {

                $element = Filter::getOption( "element", "field" );

                $condition = Filter::getOption( 'condition' );

                $data = Filter::getOption( 'value' );

                $comparison = Filter::getOption( 'comparison' );

                $queryCondition = " OR ";

                $rule = "";

                if ( "string" === $comparison ) {
                        $rule = Filter::bulidRule( static::getTableAlias( 'terms' ) . '.`name`', $data, $condition, $comparison );
                        $rule .= $queryCondition . Filter::bulidRule( static::getTableAlias( 'terms' ) . '.`slug`', $data, $condition, $comparison );
                }

                if ( is_numeric( $data ) ) {
                        $rule = (Helper::isNonEmptyStr( $rule ) ? $rule . $queryCondition : "") . Filter::bulidRule( static::getTableAlias( 'terms' ) . '.`term_id`', $data, $condition, $comparison );
                }

                $itemMetaAlias = ItemMeta::getTableAlias();

                $itemMetaQuery = $itemMetaAlias . ".`meta_key` = '_product_id' AND " . $itemMetaAlias . ".`meta_value` > 0";

                $rule = $itemMetaQuery . " AND " . DB::wpdb()->prepare( static::getTableAlias( 'term_taxonomy' ) . '.`taxonomy` = %s', $element ) . " AND ( " . $rule . " )";

                Filter::addWhere( $rule );
        }

        
        private static function addNotRule() {

                $element = Filter::getOption( "element", "field" );

                $condition = substr( Filter::getOption( "condition" ), 4 );

                $data = Filter::getOption( 'value' );

                $queryCondition = " OR ";

                $alias         = Helper::randStr( "wpie_" );
                $itemAlias     = $alias . "items";
                $itemMetaAlias = $alias . "itemmeta";
                $termAlias     = $alias . 'term';
                $termRelAlias  = $alias . 'tr';
                $termTaxAlias  = $alias . 'tt';

                $comparison = Filter::getOption( 'comparison' );

                $rule = "";

                if ( "string" === $comparison ) {
                        $rule = Filter::bulidRule( $termAlias . '.`name`', $data, $condition, $comparison );
                        $rule .= $queryCondition . Filter::bulidRule( $termAlias . '.`slug`', $data, $condition, $comparison );
                }

                if ( is_numeric( $data ) ) {
                        $rule = (Helper::isNonEmptyStr( $rule ) ? $rule . $queryCondition : "") . Filter::bulidRule( $termAlias . '.`term_id`', $data, $condition, $comparison );
                }

                $subQuery = DB::wpdb()->prepare(
                        "SELECT DISTINCT " . DB::wpdb()->posts . ".`ID` FROM " . DB::wpdb()->posts .
                        " LEFT JOIN " . DB::wpdb()->term_relationships . " AS " . $termRelAlias . " ON (" . DB::wpdb()->posts . ".`ID` = " . $termRelAlias . ".`object_id`)" .
                        " LEFT JOIN " . DB::wpdb()->term_taxonomy . " AS " . $termTaxAlias . " ON (" . $termTaxAlias . ".`term_taxonomy_id` = " . $termRelAlias . ".`term_taxonomy_id`)" .
                        " LEFT JOIN " . DB::wpdb()->terms . " AS " . $termAlias . " ON (" . $termAlias . ".`term_id`= " . $termTaxAlias . ".`term_id`)" .
                        " WHERE ( " . $rule . " )  AND " . $termTaxAlias . ".`taxonomy` = %s AND " . DB::wpdb()->posts . ".`post_type` IN ('product', 'product_variation') ",
                        $element
                );

                $itemQuery = " SELECT DISTINCT " . $itemAlias . ".`order_id` FROM " . DB::table( 'woocommerce_order_items' ) . " AS " . $itemAlias .
                        " LEFT JOIN " . DB::table( 'woocommerce_order_itemmeta' ) . " AS " . $itemMetaAlias . " ON (" . $itemMetaAlias . ".`order_item_id` = " . $itemAlias . ".`order_item_id` )" .
                        " Where " . $itemMetaAlias . ".`meta_key` = '_product_id' AND " . $itemMetaAlias . ".`meta_value` > 0 AND " . $itemMetaAlias . ".`meta_value` IN(" . $subQuery . ") ";

                Filter::addWhere( static::getOrderTableAlias() . ".`id` NOT IN(" . $itemQuery . ") AND " . static::getOrderTableAlias() . ".`" . static::getTableAliasField() . "` NOT IN(" . $itemQuery . ")" );
        }

        
        public static function addJoinQuery() {

                if ( static::$isJoinQueryAdded ) {
                        return;
                }

                static::$isJoinQueryAdded = true;

                ItemMeta::addJoinQuery();

                $itemMetaAlias = ItemMeta::getTableAlias();

                Filter::addJoin( "LEFT JOIN " . DB::wpdb()->term_relationships . " AS " . static::getTableAlias( 'term_relationships' ) . " ON (" . $itemMetaAlias . ".`meta_value` = " . static::getTableAlias( 'term_relationships' ) . ".`object_id`)" );
                Filter::addJoin( "LEFT JOIN " . DB::wpdb()->term_taxonomy . " AS " . static::getTableAlias( 'term_taxonomy' ) . " ON (" . static::getTableAlias( 'term_taxonomy' ) . ".`term_taxonomy_id` = " . static::getTableAlias( 'term_relationships' ) . ".`term_taxonomy_id`)" );
                Filter::addJoin( "LEFT JOIN " . DB::wpdb()->terms . " AS " . static::getTableAlias( 'terms' ) . " ON (" . static::getTableAlias( 'terms' ) . ".`term_id` = " . static::getTableAlias( 'term_taxonomy' ) . ".`term_id`)" );
        }

        
        public static function getOrderTableAlias() {

                return Order::getTableAlias();
        }

        
        public static function getTableAliasField() {

                return 'parent_order_id';
        }
}
