<?php



namespace WpieApp\Extensions\Export\YoastSeo\Controller\Items\User\Fields;

use WPSEO_Options;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;
use WpieApp\Modules\Export\Controller\Items\User\Fields\Meta as UserMeta;

defined( 'WPIE__FILE__' ) || exit;


class Seo implements InterfaceField {

        
        const FIELD_TYPE = "yoast-seo";

        
        public static function get() {

                $fields = [
                        "title"      => \esc_html__( "Yoast SEO", 'wp-import-export' ),
                        "priority"   => 28,
                        "isFiltered" => false,
                        "data"       => self::getFields()
                ];

                
                return \apply_filters( 'Wpie/Export/User/Fields/YoastSeo', $fields, Settings::getContentType() );
        }

        
        protected static function getFields() {

                return array_merge(
                        self::getGeneralFields(),
                        self::getSocialFields(),
                        self::getSchemaBasicFields(),
                        self::getSchemaExtraFields(),
                        self::getSchemaEmployerFields()
                );
        }

        
        protected static function getGeneralFields() {

                $fields = [
                        //Facebook
                        [ 'label' => 'SEO Title', 'type' => UserMeta::FIELD_TYPE, 'element' => 'wpseo_title' ],
                        [ 'label' => 'SEO Meta description', 'type' => UserMeta::FIELD_TYPE, 'element' => 'wpseo_metadesc' ],
                        [ 'label' => 'SEO Robots No Index', 'type' => UserMeta::FIELD_TYPE, 'element' => 'wpseo_noindex_author' ],
                        [ 'label' => 'SEO Disable SEO analysis', 'type' => UserMeta::FIELD_TYPE, 'element' => 'wpseo_keyword_analysis_disable' ],
                        [ 'label' => 'SEO Disable readability analysis', 'type' => UserMeta::FIELD_TYPE, 'element' => 'wpseo_content_analysis_disable' ],
                ];

                if ( WPSEO_Options::get( 'inclusive_language_analysis_active', false ) ) {
                        $fields[] = [ 'label' => 'SEO Disable inclusive language analysis', 'type' => UserMeta::FIELD_TYPE, 'element' => 'wpseo_inclusive_language_analysis_disable' ];
                }

                return $fields;
        }

        
        protected static function getSocialFields() {

                return [
                        //Facebook
                        [ 'label' => 'SEO Facebook profile URL', 'type' => UserMeta::FIELD_TYPE, 'element' => 'facebook' ],
                        [ 'label' => 'SEO Instagram profile URL', 'type' => UserMeta::FIELD_TYPE, 'element' => 'instagram' ],
                        [ 'label' => 'SEO LinkedIn profile URL', 'type' => UserMeta::FIELD_TYPE, 'element' => 'linkedin' ],
                        [ 'label' => 'SEO MySpace profile URL', 'type' => UserMeta::FIELD_TYPE, 'element' => 'myspace' ],
                        [ 'label' => 'SEO Pinterest profile URL', 'type' => UserMeta::FIELD_TYPE, 'element' => 'pinterest' ],
                        [ 'label' => 'SEO SoundCloud profile URL', 'type' => UserMeta::FIELD_TYPE, 'element' => 'soundcloud' ],
                        [ 'label' => 'SEO Tumblr profile URL', 'type' => UserMeta::FIELD_TYPE, 'element' => 'tumblr' ],
                        [ 'label' => 'SEO Twitter username (without @)', 'type' => UserMeta::FIELD_TYPE, 'element' => 'twitter' ],
                        [ 'label' => 'SEO YouTube profile URL', 'type' => UserMeta::FIELD_TYPE, 'element' => 'youtube' ],
                        [ 'label' => 'SEO Wikipedia page about you', 'type' => UserMeta::FIELD_TYPE, 'element' => 'wikipedia' ],
                        [ 'label' => 'SEO Mastodon profile URL', 'type' => UserMeta::FIELD_TYPE, 'element' => 'mastodon' ]
                ];
        }

        
        protected static function getSchemaBasicFields() {

                if ( !\defined( 'WPSEO_PREMIUM_VERSION' ) ) {
                        return [];
                }

                return [
                        //Facebook
                        [ 'label' => 'SEO Honorific prefix', 'type' => self::FIELD_TYPE, 'element' => 'schema-honorificPrefix' ],
                        [ 'label' => 'SEO Honorific suffix', 'type' => self::FIELD_TYPE, 'element' => 'schema-honorificSuffix' ],
                        [ 'label' => 'SEO Birth date', 'type' => self::FIELD_TYPE, 'element' => 'schema-birthDate' ],
                        [ 'label' => 'SEO Gender', 'type' => self::FIELD_TYPE, 'element' => 'schema-gender' ]
                ];
        }

        
        protected static function getSchemaExtraFields() {

                if ( !\defined( 'WPSEO_PREMIUM_VERSION' ) ) {
                        return [];
                }
                return [
                        //Facebook
                        [ 'label' => 'SEO Awards', 'type' => self::FIELD_TYPE, 'element' => 'schema-award' ],
                        [ 'label' => 'SEO Expertise in', 'type' => self::FIELD_TYPE, 'element' => 'schema-knowsAbout' ],
                        [ 'label' => 'SEO Language(s) spoken', 'type' => self::FIELD_TYPE, 'element' => 'schema-knowsLanguage' ]
                ];
        }

        
        protected static function getSchemaEmployerFields() {

                if ( !\defined( 'WPSEO_PREMIUM_VERSION' ) ) {
                        return [];
                }

                return [
                        //Facebook
                        [ 'label' => 'SEO Job title', 'type' => self::FIELD_TYPE, 'element' => 'schema-jobTitle' ],
                        [ 'label' => 'SEO Employer name', 'type' => self::FIELD_TYPE, 'element' => 'schema-worksFor' ]
                ];
        }
}
