<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\AutoDetect as Base;

defined( 'WPIE__FILE__' ) || exit;


class AutoDetect extends Base {

        
        protected static function processField( $field = '' ) {
   
                static::updateStandard( $field );

                static::updateOther( $field );

                static::updateCustomer( $field );

                static::updatePayment( $field );

                static::updateBilling( $field );

                static::updateShipping( $field );

                static::updateProduct( $field );

                static::updateFee( $field );

                static::updateCoupon( $field );

                static::updateShippingMethod( $field );

                static::updateTax( $field );

                static::updateDownload( $field );

                static::updateRefunds( $field );

                static::updateNotes( $field );
             
        }

        
        protected static function updateStandard( $field = "" ) {

                $fields = [
                        'orderkey'      => 'key',
                        'orderid'       => 'order-number',
                        'orderdate'     => 'date',
                        'completeddate' => 'date-completed',
                        'orderstatus'   => 'status',
                        'ordertotal'    => 'total',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'standard/' . $fields[ $field ], $field );
        }

        
        protected static function updateOther( $field = "" ) {

                $fields = [
                        'isvatexempt' => 'vat-exempt',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'other/' . $fields[ $field ], $field );
        }

        
        protected static function updateCustomer( $field = "" ) {

                $fields = [
                        'customeruseremail' => 'user',
                        'customeripaddress' => 'ip-adress',
                        'customernote'      => 'note',
                        'customeruseragent' => 'user-agent',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'customer/' . $fields[ $field ], $field );
        }

        
        protected static function updatePayment( $field = "" ) {

                $fields = [
                        'paymentmethod' => 'method',
                        'ordercurrency' => 'currency',
                        'transactionid' => 'transaction-id',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'payment/' . $fields[ $field ], $field );
        }

        
        protected static function updateBilling( $field = "" ) {

                $fields = [
                        'billingfirstname' => 'first-name',
                        'billinglastname'  => 'last-name',
                        'billingcompany'   => 'company',
                        'billingaddress1'  => 'address-1',
                        'billingaddress2'  => 'address-2',
                        'billingcity'      => 'city',
                        'billingpostcode'  => 'postcode',
                        'billingcountry'   => 'country',
                        'billingstate'     => 'state',
                        'billingemail'     => 'email',
                        'billingphone'     => 'phone',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'billing/' . $fields[ $field ], $field );
        }

        
        protected static function updateShipping( $field = "" ) {

                $fields = [
                        'shippingfirstname' => 'first-name',
                        'shippinglastname'  => 'last-name',
                        'shippingcompany'   => 'company',
                        'shippingaddress1'  => 'address-1',
                        'shippingaddress2'  => 'address-2',
                        'shippingcity'      => 'city',
                        'shippingpostcode'  => 'postcode',
                        'shippingcountry'   => 'country',
                        'shippingstate'     => 'state',
                        'shippingphone'     => 'phone',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'shipping/' . $fields[ $field ], $field );
        }

        
        protected static function updateProduct( $field = "" ) {

                $fields = [
                        'productname'         => 'name',
                        'itemname'            => 'item-name',
                        'quantity'            => 'quantity',
                        'itemcost'            => 'item-subtotal',
                        'itemtotal'           => 'item-total',
                        'itemtaxsubtotal'     => 'subtotal-tax',
                        'itemtaxtotal'        => 'total-tax',
                        'variationattributes' => 'variation-attributes',
                        'sku'                 => 'sku',
                        'itemmeta'            => 'meta',
                ];
                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'product/' . $fields[ $field ], $field );
        }

        
        protected static function updateFee( $field = "" ) {

                $fields = [
                        'feename'   => 'name',
                        'feeamount' => 'amount',
                        'feetaxes'  => 'tax',
                ];
                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'fee/' . $fields[ $field ], $field );
        }

        
        protected static function updateCoupon( $field = "" ) {

                $fields = [
                        'couponsname'   => 'code',
                        'couponsamount' => 'amount',
                        'couponstax'    => 'tax',
                ];
                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'coupon/' . $fields[ $field ], $field );
        }

        
        protected static function updateShippingMethod( $field = "" ) {

                $fields = [
                        'shippingname'   => 'name',
                        'shippingmethod' => 'method',
                        'shippingcost'   => 'cost',
                        'shippingtaxes'  => 'tax',
                        'shippingmeta'   => 'meta',
                ];
                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'shipping-method/' . $fields[ $field ], $field );
        }
        
        protected static function updateTax( $field = "" ) {

                $fields = [
                        'taxratelabel'      => 'name',
                        'taxratecode'       => 'code',
                        'taxratepercentage' => 'percent',
                        'taxtotal'          => 'total',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'tax/' . $fields[ $field ], $field );
        }
        
        protected static function updateDownload( $field = "" ) {

                 $fields = [
                        'downloadid'            => 'id',
                        'downloadproduct'       => 'product',
                        'downloadfile'          => 'file',
                        'downloadremaining'     => 'remaining',
                        'downloadaccessgranted' => 'access-granted',
                        'downloadaccessexpires' => 'access-expires',
                        'downloadcount'         => 'count',
                        'downloadlog'           => 'log',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'download/' . $fields[ $field ], $field );
        }
        
        protected static function updateNotes( $field = "" ) {

                 $fields = [
                        'notecontent'    => 'content',
                        'notedate'       => 'date',
                        'notevisibility' => 'visibility',
                        'noteuser'       => 'user',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'note/' . $fields[ $field ], $field );
        }
        
        protected static function updateRefunds( $field = "" ) {

                 $fields = [
                        'refundamounts'       => 'amount',
                        'refundreason'        => 'reason',
                        'refundby'            => 'refund-by',
                        'refunddate'          => 'date',
                        'refunditems'         => 'items',
                        'refunditemquantity'  => 'quantity',
                        'refunditemtotal'     => 'total',
                        'refunditemtax'       => 'tax',
                        'refundfee'           => 'fee',
                        'refundfeetax'        => 'fee-tax',
                        'refundfeetotal'      => 'fee-total',
                        'refundshipping'      => 'shipping',
                        'refundshippingtax'   => 'shipping-tax',
                        'refundshippingtotal' => 'shipping-total',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'refund/' . $fields[ $field ], $field );
        }
}
