<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\Engines\Items;

use WC_Order_Item_Fee;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Notes extends Base {

        
        private static $notes;

        
        private static $orderId = 0;

        
        protected static function update() {

                self::setAuthor();

                if ( is_null( self::$item ) ) {
                        self::create();
                        return;
                }
                self::updateNote();
        }

        
        public static function create() {

                $isCustomerNote = isset( self::$data[ 'is_customer_note' ] ) ? self::$data[ 'is_customer_note' ] : false;

                $note = \apply_filters(
                        'woocommerce_new_order_note_data',
                        [
                                'comment_post_ID'      => DataCenter::getId(),
                                'comment_author'       => isset( self::$data[ 'author' ] ) ? Helper::sanitizeText( self::$data[ 'author' ] ) : '',
                                'comment_author_email' => isset( self::$data[ 'author_email' ] ) ? Helper::sanitizeText( self::$data[ 'author_email' ] ) : '',
                                'comment_author_url'   => '',
                                'comment_content'      => isset( self::$data[ 'content' ] ) ? Helper::sanitizeText( self::$data[ 'content' ] ) : '',
                                'comment_agent'        => 'WooCommerce',
                                'comment_type'         => 'order_note',
                                'comment_parent'       => 0,
                                'comment_approved'     => 1,
                                'comment_date'         => isset( self::$data[ 'date' ] ) ? Helper::sanitizeText( self::$data[ 'date' ] ) : '',
                        ],
                        [
                                'order_id'         => DataCenter::getId(),
                                'is_customer_note' => $isCustomerNote ? 1 : 0,
                        ]
                );

                $commentId = \wp_insert_comment( $note );

                if ( $isCustomerNote ) {

                        \add_comment_meta( $commentId, 'is_customer_note', 1 );

                        \do_action(
                                'woocommerce_new_customer_note',
                                [
                                        'order_id'      => DataCenter::getId(),
                                        'customer_note' => $note[ 'comment_content' ],
                                ]
                        );
                }

                
                do_action( 'woocommerce_order_note_added', $commentId, DataCenter::getItem() );

                return $commentId;
        }

        
        private static function updateNote() {

                $note = [];

                if ( isset( self::$item->id ) && self::$item->id > 0 ) {
                        $note[ 'comment_ID' ] = self::$item->id;
                } else {
                        return;
                }

                if ( isset( self::$data[ 'author' ] ) ) {
                        $note[ 'comment_author' ] = self::$data[ 'author' ];
                }
                if ( isset( self::$data[ 'author_email' ] ) ) {
                        $note[ 'comment_author_email' ] = self::$data[ 'author_email' ];
                }

                if ( isset( self::$data[ 'content' ] ) ) {
                        $note[ 'comment_content' ] = self::$data[ 'content' ];
                }
                if ( isset( self::$data[ 'date' ] ) ) {
                        $note[ 'comment_date' ] = self::$data[ 'date' ];
                }

                $isCustomerNote = isset( self::$data[ 'is_customer_note' ] ) ? self::$data[ 'is_customer_note' ] : '';

                $result = \wp_update_comment( $note, true );

                if ( $isCustomerNote ) {
                        \update_comment_meta( $note[ 'comment_ID' ], 'is_customer_note', 1 );
                }
        }

        
        protected static function setItem() {

                if ( DataCenter::isNewItem() ) {
                        return;
                }

                self::setNotes();

                $noteContent = isset( self::$data[ 'content' ] ) ? self::$data[ 'content' ] : '';

                if ( !Helper::isNonEmptyArray( self::$notes ) || !Helper::isNonEmptyStr( $noteContent ) ) {
                        return;
                }

                foreach ( self::$notes as $note ) {

                        $content = isset( $note->content ) ? $note->content : '';

                        if ( $noteContent === $content ) {
                                self::$item = $note;
                                break;
                        }
                }

                unset( $noteContent );
        }

        
        private static function setNotes() {

                if ( self::$orderId === DataCenter::getId() ) {
                        return;
                }

                self::$orderId = DataCenter::getId();

                self::$notes = \wc_get_order_notes( [ 'order_id' => DataCenter::getId() ] );
        }

        
        private static function setAuthor() {

                if ( !isset( self::$data[ 'user' ] ) || !Helper::isNonEmptyStr( self::$data[ 'user' ] ) ) {
                        return;
                }

                $user = \get_user_by( 'login', self::$data[ 'user' ] );

                if ( $user === false || !isset( $user->ID ) ) {
                        $user = \get_user_by( 'email', self::$data[ 'user' ] );
                }
                if ( $user === false || !isset( $user->ID ) ) {
                        return;
                }
                self::$data[ 'author' ]       = isset( $user->user_login ) ? $user->user_login : '';
                self::$data[ 'author_email' ] = isset( $user->user_email ) ? $user->user_email : '';
        }
}
