<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\Engines\Items;

use WpieApp\Core\Utils\Date;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\User\Search;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Refund extends Base {

        
        protected static function processItem() {

                self::$data[ 'line_items' ] = [];

                self::setLineItems();
        }

        
        protected static function update() {

                $args = [];

                if ( isset( self::$data[ 'amount' ] ) ) {
                        $args[ 'amount' ] = abs( floatval( self::$data[ 'amount' ] ) );
                }
                if ( isset( self::$data[ 'reason' ] ) ) {
                        $args[ 'reason' ] = self::$data[ 'reason' ];
                }
                if ( isset( self::$data[ 'date_created' ] ) ) {
                        $args[ 'date_created' ] = self::$data[ 'date_created' ];
                }
                if ( isset( self::$data[ 'line_items' ] ) ) {
                        $args[ 'line_items' ] = self::$data[ 'line_items' ];
                }
                if ( !is_null( self::$item ) ) {
                        $args[ 'refund_id' ] = self::$item->get_id();
                }

                if ( !Helper::isNonEmptyArray( $args ) ) {
                        return;
                }

                $args[ 'order_id' ] = DataCenter::getId();

                $refund = \wc_create_refund( $args );

                if ( \is_wp_error( $refund ) ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $refund->get_error_message() );

                        return 0;
                }

                self::setRefundBy( $refund );

                return $refund->get_id();
        }

        
        protected static function setRefundBy( $refund ) {

                if ( !isset( self::$data[ 'refund-by' ] ) || !Helper::isNonEmptyStr( self::$data[ 'refund-by' ] ) ) {
                        return;
                }

                $userId = Search::getUserIdBy( 'email', self::$data[ 'refund-by' ] );

                if ( $userId < 1 || $userId === $refund->get_refunded_by() ) {
                        return;
                }

                $refund->set_refunded_by( $userId );

                $refund->save();
        }

        
        protected static function setItem() {

                if ( DataCenter::isNewItem() ) {
                        return;
                }

                $items = DataCenter::getItem()->get_refunds();

                $dateCreated = isset( self::$data[ 'date_created' ] ) ? self::$data[ 'date_created' ] : '';

                if ( !Helper::isNonEmptyArray( $items ) || !Helper::isNonEmptyStr( $dateCreated ) ) {
                        return;
                }

                $dateCreated = Date::get( $dateCreated );

                foreach ( $items as $item ) {

                        $refundDateCreated = $item->get_date_created();

                        if ( $dateCreated === $refundDateCreated->date_i18n( Date::FORMAT ) ) {
                                self::$item = $item;
                                break;
                        }
                }

                unset( $items, $dateCreated );
        }

        
        protected static function setLineItems() {

                self::setLineItem( 'line_item' );

                self::setLineItem( 'fee' );

                self::setLineItem( 'shipping' );
        }

        
        protected static function setLineItem( $type = '' ) {

                $inputItems = isset( self::$data[ $type ] ) ? self::$data[ $type ] : [];

                if ( !Helper::isNonEmptyArray( $inputItems ) ) {
                        return;
                }

                $items = DataCenter::getItem()->get_items( [ $type ] );

                if ( !Helper::isNonEmptyArray( $items ) ) {
                        return;
                }


                foreach ( $items as $itemId => $item ) {

                        foreach ( $inputItems as $inputItem ) {

                                $name = isset( $inputItem[ 'name' ] ) ? $inputItem[ 'name' ] : '';

                                if ( $name === $item->get_name() ) {
                                        self::$data[ 'line_items' ][ $itemId ] = $inputItem;
                                        break;
                                }
                        }
                }


                unset( $items, $inputItems );
        }
}
