<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\AutoDetect;

use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\AutoDetect as Base;

defined( 'WPIE__FILE__' ) || exit;


class Attributes {

        
        protected static $attributes = [];

        
        protected static $attributeFields = [];

        
        protected static $keys = [];

        
        public static function get( $fields = [], $keys = [] ) {

                self::$keys = $keys;

                self::setAttributes( $fields );

                self::createAttributes();

                return self::getFields();
        }

        
        public static function setAttributes( $fields = [] ) {

                self::$attributes = [];

                self::$attributeFields = [];

                if ( !Helper::isNonEmptyArray( $fields ) ) {
                        return;
                }

                foreach ( $fields as $field ) {

                        $type = isset( $field[ 'type' ] ) ? $field[ 'type' ] : '';

                        if ( !in_array( $type, [ 'attribute', 'text' ] ) ) {
                                continue;
                        }

                        $element = isset( $field[ 'element' ] ) ? $field[ 'element' ] : '';

                        $label = isset( $field[ 'label' ] ) ? Helper::sanitizeKey( $field[ 'label' ] ) : '';

                        $key = static::getKey( $label );

                        if ( !isset( self::$attributes[ $element ] ) ) {
                                self::$attributes[ $element ] = [];
                        }
                        self::$attributeFields[] = $label;

                        if ( !in_array( $label, self::$keys ) ) {
                                $label = '';
                        }

                        if ( in_array( $key, [ 'name', 'slug' ] ) ) {
                                $label = isset( $field[ 'data' ] ) ? $field[ 'data' ] : '';
                        } elseif ( 'is_taxonomy' === $key ) {
                                $label = isset( $field[ 'data' ] ) ? $field[ 'data' ] : '';
                        } else {
                                $label = Base::formatField( $label );
                        }

                        self::$attributes[ $element ][ $key ] = $label;
                }
        }

        
        public static function createAttributes() {

                $fields = array_diff( self::$keys, self::$attributeFields );

                if ( !Helper::isNonEmptyArray( $fields ) ) {
                        return;
                }

                $attributes = [];

                foreach ( $fields as $field ) {

                        $attribute = static::getname( $field );

                        $key = static::getKey( $field );

                        if ( !isset( $attributes[ $attribute ] ) ) {
                                $attributes[ $attribute ] = [];
                        }

                        $attributes[ $attribute ][ $key ] = Base::formatField( $field );
                }

                self::$attributes = array_replace( $attributes, self::$attributes );
        }

        protected static function getFields() {

                if ( !Helper::isNonEmptyArray( self::$attributes ) ) {
                        return [];
                }

                $attributes = [];

                foreach ( self::$attributes as $fields ) {

                        foreach ( $fields as $key => $field ) {

                                $attributes[ $key ][] = in_array( $key, [ 'name', 'value' ] ) ? $field : [ "data" => "as_specified", "data_as_specified" => $field ];
                        }
                }


                foreach ( $attributes as $fields ) {

                        foreach ( $fields as $field ) {

                                $attributes[ 'separator' ][] = [ 'data' => '||' ];
                        }
                        break;
                }

                return $attributes;
        }

        
        public static function getKey( $field = "" ) {

                if ( Helper::strStartsWith( 'attributename', $field ) ) {
                        return 'name';
                } elseif ( Helper::strStartsWith( 'attributevalue', $field ) ) {
                        return 'value';
                } elseif ( Helper::strStartsWith( 'attributeslug', $field ) ) {
                        return 'slug';
                } elseif ( Helper::strStartsWith( 'attributeinvariations', $field ) ) {
                        return 'in_variations';
                } elseif ( Helper::strStartsWith( 'attributeisvisible', $field ) ) {
                        return 'is_visible';
                } elseif ( Helper::strStartsWith( 'attributeistaxonomy', $field ) ) {
                        return 'is_taxonomy';
                } elseif ( Helper::strStartsWith( 'attributeposition', $field ) ) {
                        return 'position';
                }
                return '';
        }

        
        public static function getname( $field = "" ) {

                if ( Helper::strStartsWith( 'attributename', $field ) ) {
                        return \mb_substr( $field, mb_strlen( 'attributename' ) );
                } elseif ( Helper::strStartsWith( 'attributevalue', $field ) ) {
                        return \mb_substr( $field, mb_strlen( 'attributevalue' ) );
                } elseif ( Helper::strStartsWith( 'attributeslug', $field ) ) {
                        return \mb_substr( $field, mb_strlen( 'attributeslug' ) );
                } elseif ( Helper::strStartsWith( 'attributeinvariations', $field ) ) {
                        return \mb_substr( $field, mb_strlen( 'attributeinvariations' ) );
                } elseif ( Helper::strStartsWith( 'attributeisvisible', $field ) ) {
                        return \mb_substr( $field, mb_strlen( 'attributeisvisible' ) );
                } elseif ( Helper::strStartsWith( 'attributeistaxonomy', $field ) ) {
                        return \mb_substr( $field, mb_strlen( 'attributeistaxonomy' ) );
                } elseif ( Helper::strStartsWith( 'attributeposition', $field ) ) {
                        return \mb_substr( $field, mb_strlen( 'attributeposition' ) );
                }
                return '';
        }
}
