<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class WcTypes {

        
        public static function init() {

                \add_filter( 'Wpie/ImpExpTypes', [ __CLASS__, 'getImpExpTypes' ] );

                \add_filter( 'Wpie/Modules/Import/View/ContentType', [ __CLASS__, 'addWcTypes' ] );

                \add_filter( 'Wpie/Import/Taxonomy/ContentType', [ __CLASS__, 'removeTaxonomies' ] );

                \add_filter( 'Wpie/Import/customPosts/ContentType', [ __CLASS__, 'removePosts' ] );

                \add_filter( 'Wpie/ImpExpTypes/Posts', [ __CLASS__, 'removePosts' ] );

                \add_filter( 'Wpie/ImpExpTypes/Taxonomy/Excludes', [ __CLASS__, 'excludeTaxonomy' ] );
        }

        
        public static function excludeTaxonomy( $taxonomies = [] ) {

                return array_merge( $taxonomies, [ 'product_cat', 'product_tag' ] );
        }

        
        public static function removeTaxonomies( $taxonomies = [] ) {

                if ( isset( $taxonomies[ 'product_cat' ] ) ) {
                        unset( $taxonomies[ 'product_cat' ] );
                }
                if ( isset( $taxonomies[ 'product_tag' ] ) ) {
                        unset( $taxonomies[ 'product_tag' ] );
                }

                return $taxonomies;
        }

        
        public static function removePosts( $posts = [] ) {

                if ( isset( $posts[ 'product' ] ) ) {
                        unset( $posts[ 'product' ] );
                }
                if ( isset( $posts[ 'shop_order' ] ) ) {
                        unset( $posts[ 'shop_order' ] );
                }
                if ( isset( $posts[ 'shop_coupon' ] ) ) {
                        unset( $posts[ 'shop_coupon' ] );
                }

                return $posts;
        }

        
        public static function addWcTypes( $data = [] ) {

                $data = Helper::isNonEmptyArray( $data ) ? $data : [];

                $data[ 'fields' ] = isset( $data[ 'fields' ] ) && Helper::isNonEmptyArray( $data[ 'fields' ] ) ? $data[ 'fields' ] : [];

                $data[ 'fields' ][ 'woocommerce' ] = [
                        "order"       => 15,
                        "wrapper-col" => "col-lg-6",
                        "label"       => __( 'WooCommerce', 'wp-import-export' ),
                        "sub-fields"  => [
                                "post" => [
                                        "pro-backdrop" => WPIE_PRO ? false : true,
                                        "col-class"    => "cols",
                                        "type"         => "radio",
                                        "order"        => 5,
                                        "name"         => "content_type",
                                        "class"        => "wpie-content-type",
                                        "default"      => "",
                                        "description"  => __( 'WooCommerce Shop Data', 'wp-import-export' ),
                                        "choices"      => self::getWcTypes(),
                                ],
                        ],
                ];

                return $data;
        }

        
        public static function getWcTypes() {

                return [
                        'wc/product'         => __( 'Products', 'wp-import-export' ),
                        'wc/product_cat'     => __( 'Product Categories', 'wp-import-export' ),
                        'wc/product_tag'     => __( 'Product Tags', 'wp-import-export' ),
                        'wc/product_reviews' => __( 'Product Reviews', 'wp-import-export' ),
                        'wc/attribute'       => __( 'Product Attributes', 'wp-import-export' ),
                        'wc/shop_order'      => __( 'Shop Orders', 'wp-import-export' ),
                        'wc/shop_customer'   => __( 'Customers', 'wp-import-export' ),
                        'wc/shop_coupon'     => __( 'Coupons', 'wp-import-export' ),
                ];
        }

        
        public static function getImpExpTypes( $types = [] ) {

                return array_replace( $types, self::getWcTypes() );
        }
}
