<?php



namespace WpieApp\Modules\Debug\View\Logs\SystemInfo;

use WpieApp\Core\Utils\DB;

defined( 'WPIE__FILE__' ) || exit;


class Database {

        
        public static function get() {

                if ( isset( DB::wpdb()->use_mysqli ) && DB::wpdb()->use_mysqli ) {
                        $clientVersion = DB::wpdb()->dbh->client_info;
                } else {
                        // phpcs:ignore WordPress.DB.RestrictedFunctions.mysql_mysql_get_client_info,PHPCompatibility.Extensions.RemovedExtensions.mysql_DeprecatedRemoved
                        if ( preg_match( '|[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}|', \mysql_get_client_info(), $matches ) ) {
                                $clientVersion = $matches[ 0 ];
                        } else {
                                $clientVersion = null;
                        }
                }


                return [
                        "label" => __( 'Database', 'wp-import-export' ),
                        "order" => 40,
                        "data"  => [
                                'extension'          => [
                                        'label' => __( 'Extension', 'wp-import-export' ),
                                        'data'  => is_resource( DB::wpdb()->dbh ) ? 'mysql' : (is_object( DB::wpdb()->dbh ) ? get_class( DB::wpdb()->dbh ) : null)
                                ],
                                'server_version'     => [
                                        'label' => __( 'Server version', 'wp-import-export' ),
                                        'data'  => DB::wpdb()->db_version(),
                                ],
                                'client_version'     => [
                                        'label' => __( 'Client version', 'wp-import-export' ),
                                        'data'  => $clientVersion
                                ],
                                'database_user'      => [
                                        'label' => __( 'Database username', 'wp-import-export' ),
                                        'data'  => DB::wpdb()->dbuser
                                ],
                                'database_host'      => [
                                        'label' => __( 'Database host', 'wp-import-export' ),
                                        'data'  => DB::wpdb()->dbhost
                                ],
                                'database_prefix'    => [
                                        'label' => __( 'Database name', 'wp-import-export' ),
                                        'data'  => DB::wpdb()->dbname
                                ],
                                'database_name'      => [
                                        'label' => __( 'Table prefix', 'wp-import-export' ),
                                        'data'  => DB::wpdb()->prefix
                                ],
                                'database_charset'   => [
                                        'label' => __( 'Database charset', 'wp-import-export' ),
                                        'data'  => DB::wpdb()->charset
                                ],
                                'database_collate'   => [
                                        'label' => __( 'Database collation', 'wp-import-export' ),
                                        'data'  => DB::wpdb()->collate
                                ],
                                'max_allowed_packet' => [
                                        'label' => __( 'Max allowed packet size', 'wp-import-export' ),
                                        'data'  => self::getMysqlVar( "max_allowed_packet" )
                                ],
                                'max_connections'    => [
                                        'label' => __( 'Max connections number', 'wp-import-export' ),
                                        'data'  => self::getMysqlVar( "max_connections" )
                                ],
                        ]
                ];
        }

        
        private static function getMysqlVar( $mysqlVar ) {

                $result = DB::wpdb()->get_row(
                        DB::wpdb()->prepare( 'SHOW VARIABLES LIKE %s', $mysqlVar ),
                        ARRAY_A
                );

                if ( !empty( $result ) && array_key_exists( 'Value', $result ) ) {
                        return $result[ 'Value' ];
                }

                return null;
        }

}
