<?php



namespace WpieApp\Modules\Export\Controller\Items\Base\Filters;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;

defined( 'WPIE__FILE__' ) || exit;


class Base {

        
        private static $filter;

        
        private static $field;

        
        private static $where = [];

        
        private static $join = [];

        
        public static function addJoin( $join = null ) {

                if ( !Helper::isNonEmptyStr( $join ) ) {
                        return;
                }

                self::$join[] = $join;
        }

        
        public static function addWhere( $where = null, $cause = "" ) {

                if ( $where === false ) {
                        self::$where[] = " 1 != 1 ";
                }
                if ( !Helper::isNonEmptyStr( $where ) ) {
                        return;
                }
                if ( !Helper::isNonEmptyStr( $cause ) ) {
                        $cause = self::addRuleSeparator();
                }

                $where = DB::removePlaceholder( $where );

                self::$where[] = " " . $cause . " ( " . $where . " ) ";
        }

        
        public static function getJoin() {
                return self::$join;
        }

        
        public static function getWhere() {
                return self::$where;
        }

        
        public static function init() {

                $filters = Settings::getOption( 'filters' );

                if ( Helper::isNonEmptyArray( self::$filter ) || !Helper::isNonEmptyArray( $filters ) ) {
                        return false;
                }

                if ( self::getFilterCache() ) {
                        return;
                }

                foreach ( $filters as $filter ) {

                        self::addFilter( $filter );
                }

                self::setFilterCache();
        }

        
        private static function getFilterCache() {

                if ( Settings::getLog( 'processed' ) <= 0 ) {
                        return false;
                }

                $where = Settings::getOption( 'query/filter/where' );

                if ( !Helper::isNonEmptyArray( $where ) ) {
                        return false;
                }

                self::$where = $where;

                self::$join = Settings::getOption( 'query/filter/join' );

                return true;
        }

        
        private static function setFilterCache() {

                Settings::setOption( 'query/filter/where', self::$where );

                Settings::setOption( 'query/filter/join', self::$join );
        }

        
        public static function addFilter( $filter = null ) {

                if ( !Helper::isNonEmptyArray( $filter ) || !isset( $filter[ 'field' ] ) ) {
                        return;
                }

                self::$filter = $filter;

                self::$field = $filter[ 'field' ];

                static::addRule();
        }

        
        public static function getOption( $option = "", $type = "filter", $default = "" ) {

                if ( !Helper::isNonEmptyStr( $option ) ) {
                        return $default;
                }

                if ( $type === "field" ) {
                        return ( isset( self::$field[ $option ] ) ? self::$field[ $option ] : $default);
                }

                return ( isset( self::$filter[ $option ] ) ? self::$filter[ $option ] : $default);
        }

        
        public static function setOption( $option = "", $value = "", $type = "filter" ) {

                if ( !Helper::isNonEmptyStr( $option ) ) {
                        return false;
                }

                if ( $type === "field" ) {
                        self::$field[ $option ] = $value;
                        return;
                }

                self::$filter[ $option ] = $value;
        }

        
        public static function bulidRule( $field = "", $data = "", $condition = "", $comparison = "" ) {

                return Rule::get( $field, $data, $condition, $comparison );
        }

        
        public static function addRuleSeparator() {

                $separator = self::getOption( 'rule_separator' );

                if ( Helper::isNonEmptyStr( $separator ) ) {
                        return " " . $separator . " ";
                }
                return "";
        }
}
