<?php



namespace WpieApp\Modules\Import\Controller\File\Filters;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Core\Office\Reader\XML\XmlNode;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Core\Resource\Resource;

defined( 'WPIE__FILE__' ) || exit;


class Xml extends Base {

        
        protected function preInit() {
        }
        
        protected function initReader() {

                $file = Settings::getImportFilePath();

                $reader = new XmlNode();

                $isLoaded = $reader->load( $file, [ 'root' => Settings::getOption( "file/root" ) ] );

                if ( is_wp_error( $isLoaded ) ) {
                        return $isLoaded;
                }

                return $reader;
        }

        
        protected function initWriter() {

                $file = Settings::getFilteredFilePath();

                $this->writer = Helper::fOpen( $file, "a+" );

                return $this->writer;
        }

        
        protected function applyFilters() {

                $this->addHeader();

                $isExceeded = false;

                while ( $this->reader->nextNode() ) {

                        if ( Resource::isExceeded() ) {
                                $isExceeded = true;
                                break;
                        }

                        $xml = $this->reader->readOuterXml();

                        $this->data = $this->reader->current();

                        if ( !Helper::isNonEmptyArray( $this->data ) ) {
                                continue;
                        }

                        if ( !$this->applyRules() ) {
                                continue;
                        }

                        fwrite( $this->writer, $xml );
                }



                if ( $isExceeded ) {

                        Settings::setOptions( [
                                "filter/status" => "pending",
                                "filter/node"   => ( string ) $this->reader->getNodeNumber(),
                        ] );

                        fclose( $this->writer );

                        return [ "status" => "processing" ];
                }

                $this->addFooter();

                fclose( $this->writer );

                Settings::setOptions( [
                        "filter/status" => "completed",
//			"filter/root"	 => Settings::getOption( "file/root" ),
                        "data/root"   => "wpiedata/" . $this->reader->getRootNode(),
                ] );

                return [ "status" => "completed" ];
        }

        
        protected function resumeTask() {

                if ( Settings::getOption( "filter/status" ) !== "pending" ) {
                        return;
                }

                $this->rules = Settings::getOption( "filter/rules" );

                $node = Settings::getOption( "filter/node" );

                $this->reader->goToRow( $node );
        }

        
        private function addHeader() {

                $header = '<?xml version="1.0" encoding="UTF-8" ?><wpiedata>';

                fwrite( $this->writer, $header );
        }

        
        private function addFooter() {

                $footer = "</wpiedata>";

                fwrite( $this->writer, $footer );
        }
}
