<?php



namespace WpieApp\Modules\Import\Controller\Items\Base;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\File\Record;
use WpieApp\Extensions\Manager as Extensions;
use WpieApp\Modules\Export\Controller\Settings as ExportSettings;
use WpieApp\Modules\Export\Controller\Items\Manager as ExportItems;

defined( 'WPIE__FILE__' ) || exit;


class AutoLoadFields {

        
        protected static $fields = [];

        
        protected static $labels = [];

        
        protected static $data = [];

        
        public static function get() {

                static::$data = [];

                static::setExportSettings();

                Settings::autoLoad();

                static::setLabels();

                static::init();

                static::processingFields();

                return static::$data;
        }

        
        protected static function init() {
                
        }

        
        protected static function setDefaults() {

                static::$data = [ 'fields' => [], "can-update" => [] ];

                //Standard fields
                if ( !isset( static::$data[ 'fields' ][ 'standard' ] ) ) {
                        static::$data[ 'fields' ][ 'standard' ] = [];
                }
        }

        
        private static function setLabels() {

                static::$labels = Record::get( "getLabels" );

                if ( "xml" === Settings::getFileFormat() ) {

                        $prefix = Settings::getOption( "file/root" ) . '/';

                        $labels = [];

                        foreach ( array_keys( static::$labels ) as $item ) {
                                if ( strpos( $item, $prefix ) === 0 ) {
                                        $labels[] = substr( $item, strlen( $prefix ) );
                                }
                        }

                        static::$labels = $labels;

                        unset( $labels );
                }
        }

        
        private static function setExportSettings() {

                if ( Helper::isNonEmptyArray( static::$fields ) ) {
                        return;
                }

                $data = [
                        "category"     => Helper::_post( "category" ),
                        "content_type" => Helper::_post( "content_type" )
                ];

                Extensions::loadExportExtensions();

                ExportSettings::autoLoadData( $data );

                static::$fields = ExportItems::get( 'fields' );
        }

        
        protected static function hasProcessed( $field = '', $type = '', $fieldOptions = [] ) {

                return \apply_filters( "Wpie/Import/Base/AutoLoadFields/processField/hasProcessed", false, $field, $type, $fieldOptions );
        }

        
        protected static function addField( $field = '', $data = '', $type = '' ) {

                if ( !isset( static::$data[ 'fields' ][ $type ] ) ) {
                        static::$data[ 'fields' ][ $type ] = [];
                }

                if ( !isset( static::$data [ 'can-update' ][ $type ] ) ) {
                        static::$data[ 'can-update' ][ $type ] = [];
                }

                static::$data[ 'fields' ][ $type ][ $field ] = [ "data" => "{" . $data . "}" ];

                static::$data[ 'can-update' ][ $type ][ $field ] = "1";
        }

        
        protected static function addMetaField( $key = "" ) {

                if ( !isset( static::$data[ 'fields' ][ 'meta' ][ 'data' ] ) ) {
                        static::$data[ 'fields' ][ 'meta' ] [ 'data' ] = [];
                }

                $metaVal = in_array( $key, static::$labels ) ? "{" . $key . "}" : "";

                static::$data[ 'fields' ][ 'meta' ][ "data" ][] = [ "key" => $key, "val" => $metaVal ];

                //Meta Fields
                static::$data[ 'can-update' ][ 'meta' ] = "1";
        }

        
        protected static function processingFields() {

                if ( !Helper::isNonEmptyArray( static::$fields ) || !Helper::isNonEmptyArray( static::$labels ) ) {
                        return;
                }

                static::setDefaults();

                foreach ( static::$fields as $fieldGroup ) {

                        if ( !Helper::isNonEmptyArray( $fieldGroup ) ) {
                                continue;
                        }

                        $fields = isset( $fieldGroup[ 'data' ] ) ? $fieldGroup[ 'data' ] : [];

                        if ( !Helper::isNonEmptyArray( $fields ) ) {
                                continue;
                        }

                        foreach ( $fields as $field ) {
                                static::setField( $field );
                        }
                }
        }

        
        protected static function setField( $field = [] ) {


                if ( !Helper::isNonEmptyArray( $field ) ) {
                        return;
                }

                $type = isset( $field[ 'type' ] ) ? $field[ 'type' ] : "";

                $label = isset( $field[ 'label' ] ) ? $field[ 'label' ] : "";

                if ( !Helper::isNonEmptyStr( $type ) || !Helper::isNonEmptyStr( $label ) ) {
                        return;
                }

                $key = Helper::sanitizeKey( $label );

                if ( !static::isValid( $key, $type ) ) {
                        return;
                }

                static::processField( $key, $type, $field );
        }

        
        protected static function isValid( $field = '', $type = '' ) {

                if ( !in_array( $field, static::$labels ) && $type !== "meta" ) {
                        return false;
                }

                return true;
        }

        
        protected static function processField( $data = '', $type = '', $fieldOptions = [] ) {
                
        }
}
