<?php



namespace WpieApp\Modules\Import\Controller\Items\Base\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Base\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Meta {

        
        protected static $data = [];

        
        public static function import() {

                if ( !DataCenter::canUpdate( "meta" ) ) {
                        return false;
                }

                if ( !static::init() ) {
                        return false;
                }

                static::processMeta();

                static::removeMeta();
                /* translators: %s: content type */
                Logger::log( sprintf( __( "%s Meta Imported", 'wp-import-export' ), Settings::getContentLabel() ) );
        }

        
        protected static function init() {

                self::$data = [];

                $metaList = DataCenter::getFieldSetting( "meta/data" );

                if ( !Helper::isNonEmptyStr( $metaList ) ) {
                        return false;
                }

                $metas = Helper::jsonDecode( $metaList );

                if ( \is_wp_error( $metas ) ) {
                        Logger::log( __( "Meta Import Error", 'wp-import-export' ) . " : " . $metas->get_error_message() );
                        return false;
                }

                self::$data = static::formatMeta( $metas );

                return Helper::isNonEmptyArray( self::$data ) ? true : false;
        }

        
        protected static function processMeta() {

                $skipEmpty = (absint( DataCenter::get( "meta/option/skip-empty" ) ) === 1);

                $data = array_diff_key( self::$data, array_flip( static::getExcludes() ) );

                foreach ( $data as $key => $val ) {

                        if ( $skipEmpty && !Helper::isNonEmptyArray( $val ) && !Helper::isNonEmptyStr( $val ) ) {
                                continue;
                        }

                        $arrayVal = (Helper::isNonEmptyStr( $val ) && Helper::isPossiblyJson( $val ) ) ? Helper::jsonDecode( $val, true ) : false;

                        if ( \is_array( $arrayVal ) ) {
                                $val = $arrayVal;
                        }

                        static::update( $key, $val );
                }

                unset( $data );
        }

        
        protected static function removeMeta() {

                if ( DataCenter::isNewItem() || DataCenter::get( "meta/option/manage-existing" ) !== "remove" ) {
                        return;
                }

                $data = array_merge( array_keys( self::$data ), static::getExcludes() );

                static::remove( $data );
        }

        
        public static function update( $key = '', $val = '' ) {

                if ( !Helper::isNonEmptyStr( $key ) ) {
                        return;
                }
                if ( \is_array( $val ) ) {
                        $val = Helper::isNonEmptyArray( $val ) ? \maybe_serialize( $val ) : '';
                }

                static::updateMeta( $key, $val );
        }

        
        public static function updateMeta( $key = '', $val = '' ) {
                
        }

        
        protected static function remove( $data = [] ) {
                
        }

        
        protected static function formatMeta( $metas ) {

                if ( Helper::isEmpty( $metas ) ) {
                        return [];
                }

                $data = [];

                foreach ( $metas as $meta ) {
                        if ( !is_object( $meta ) ) {
                                continue;
                        }
                        $key          = isset( $meta->key ) ? DataCenter::getFileData( $meta->key ) : null;
                        $val          = isset( $meta->val ) ? $meta->val : "";
                        $data[ $key ] = is_array( $val ) ? static::formatMeta( $val ) : DataCenter::getFileData( $val );
                }

                return $data;
        }

        
        protected static function getExcludes() {

                return [];
        }
}
