<?php



namespace WpieApp\Modules\Import\Controller\Items\Base;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;

defined( 'WPIE__FILE__' ) || exit;


class Shortcode {

        
        public static function apply( $data ) {
                
                $data = self::init( $data );

                return self::decode( $data );
        }

        
        public static function decode( $data = [] ) {

                return \str_replace( [ "wpie_square_bracket_open", "wpie_square_bracket_close", "wpie_double_quote", "wpie_single_quote" ], [ "[", "]", '"', "'" ], $data );
        }

        
        public static function encode( $data = [] ) {

                return \str_replace( [ "[", "]", '"', "'" ], [ "wpie_square_bracket_open", "wpie_square_bracket_close", "wpie_double_quote", "wpie_single_quote" ], $data );
        }

        
        public static function init( $content = "" ) {

                if ( empty( $content ) ) {
                        return $content;
                }

                if ( is_array( $content ) ) {
                        return array_map( [ __CLASS__, "init" ], $content );
                }

                if ( !self::hasShortcode( $content ) ) {
                        return $content;
                }

                return self::doShortcode( wp_unslash( $content ) );
        }

        
        public static function hasShortcode( $content = "" ) {

                return Helper::contains( $content, '[wpie_function' );
        }

        
        public static function doShortcode( $content = "", $ignoreHtml = false ) {

                $matches  = null;
                // Find all registered tag names in $content.
                preg_match_all( '@\[([^<>&/\[\]\x00-\x20=]++)@', $content, $matches );
                $tagnames = array_intersect( [ 'wpie_function' ], $matches[ 1 ] );

                if ( !Helper::isNonEmptyArray( $tagnames ) ) {
                        return $content;
                }

                $content = \do_shortcodes_in_html_tags( $content, $ignoreHtml, $tagnames );

                $pattern = \get_shortcode_regex( $tagnames );
                $content = \preg_replace_callback( "/$pattern/", [ __CLASS__, 'doShortcodeTag' ], $content );

                // Always restore square braces so we don't break things like <!--[if IE ]>.
                $content = \unescape_invalid_shortcodes( $content );

                return $content;
        }

        
        public static function doShortcodeTag( $m ) {

                // Allow [[foo]] syntax for escaping a tag.
                if ( '[' === $m[ 1 ] && ']' === $m[ 6 ] ) {
                        return substr( $m[ 0 ], 1, -1 );
                }

                $attr = \shortcode_parse_atts( $m[ 3 ] );

                $content = isset( $m[ 5 ] ) ? $m[ 5 ] : null;

                return $m[ 1 ] . self::process( $content, $attr ) . $m[ 6 ];
        }

        
        public static function process( $content = "", $attr = [] ) {

                if ( !Helper::isNonEmptyArray( $attr ) ) {
                        return "";
                }

                $customFunction = "";

                if ( isset( $attr[ 'custom_function' ] ) ) {
                        $customFunction = $attr[ 'custom_function' ];
                        unset( $attr[ 'custom_function' ] );
                }

                if ( !Helper::isNonEmptyStr( $customFunction ) ) {
                        foreach ( $attr as $key => $value ) {
                                if ( strtotime( trim( $customFunction ) ) === "custom_function" ) {
                                        $customFunction = $value;
                                        unset( $attr[ $key ] );
                                        break;
                                }
                        }
                }

                if ( !Helper::isNonEmptyStr( $customFunction ) || !is_callable( $customFunction ) ) {
                        return "";
                }

                $newAttr = [];
                if ( !empty( $attr ) ) {
                        foreach ( $attr as $key => $value ) {
                                $key             = preg_replace( "/[^a-zA-Z0-9]+/", "", self::decode( $key ) );
                                $value           = self::decode( $value );
                                $newAttr[ $key ] = $value;
                        }
                }

                return call_user_func( $customFunction, $newAttr, $content );
        }
}
