<?php



namespace WpieApp\Modules\Import\Controller\Items\Comment\Engines;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Comment\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Standard {

        
        public static function get() {

                $data = [];

                if ( DataCenter::canUpdate( "standard/content" ) ) {
                        $data[ "comment_content" ] = DataCenter::get( "standard/content/data" );
                }

                if ( DataCenter::canUpdate( "standard/type" ) ) {

                        $type = DataCenter::get( "standard/type/data" );

                        if ( Helper::isNonEmptyStr( $type ) ) {
                                $data[ "comment_type" ] = $type;
                        }
                }
                if ( DataCenter::canUpdate( "standard/parent" ) ) {
                        $data[ "comment_parent" ] = self::getParent();
                }

                if ( DataCenter::canUpdate( "standard/date" ) ) {

                        $date = self::getDate( DataCenter::get( "standard/date/data" ) );

                        if ( Helper::isNonEmptyStr( $date ) ) {
                                $data[ "comment_date" ] = $date;
                        }
                        unset( $date );
                }
                if ( DataCenter::canUpdate( "standard/date_gmt" ) ) {

                        $date = self::getDate( DataCenter::get( "standard/date_gmt/data" ) );

                        if ( Helper::isNonEmptyStr( $date ) ) {
                                $data[ "comment_date_gmt" ] = $date;
                        }

                        unset( $date );
                }
                if ( DataCenter::canUpdate( "standard/approved" ) ) {
                        $data[ "comment_approved" ] = Helper::detectBoolVal( DataCenter::get( "standard/approved/data" ) ) === false ? 0 : 1;
                }


                return $data;
        }

        
        public static function getDate( $date = '' ) {

                if ( !Helper::isNonEmptyStr( $date ) ) {
                        return '';
                }

                $date = ( "now" === $date || \strtotime( $date ) === false ) ? Date::now() : $date;

                return Date::get( $date );
        }

        
        private static function getParent() {

                $postId = self::getPostId();

                if ( $postId < 1 ) {
                        return 0;
                }

                $content = DataCenter::get( "parent/content/data" );

                if ( !Helper::isNonEmptyStr( $content ) ) {
                        return 0;
                }

                $query = '';

                $date = DataCenter::get( "parent/date/data" );

                if ( 'now' !== $date && Helper::isNonEmptyStr( $date ) ) {
                        $date  = self::getDate( $date );
                        $query = Helper::isNonEmptyStr( $date ) ? DB::wpdb()->prepare( 'AND ( `comment_date` = %s OR `comment_date_gmt` = %s )', $date, $date ) : '';
                }

                return DB::wpdb()->get_var(
                                DB::wpdb()->prepare(
                                        'SELECT `comment_ID` FROM ' . DB::wpdb()->comments
                                        . ' WHERE  `comment_content` = %s AND `comment_post_ID` = %d ' . $query . ' ORDER BY `comment_ID` ASC',
                                        $content,
                                        $postId
                                )
                );
        }

        
        private static function getPostId() {

                if ( DataCenter::isNewItem() ) {

                        $post = Post::get();

                        return ( isset( $post[ 'comment_post_ID' ] ) && absint( $post[ 'comment_post_ID' ] ) > 0 ) ? $post[ 'comment_post_ID' ] : 0;
                }

                $commentId = DataCenter::getId();

                $comment = \get_comment( $commentId );

                return (is_object( $comment ) && $comment->comment_post_ID) ? $comment->comment_post_ID : 0;
        }
}
