<?php



namespace WpieApp\Modules\Import\Controller;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\File\Filter;
use WpieApp\Modules\Import\Controller\File\Record;
use WpieApp\Modules\Import\Controller\File\Setup;
use WpieApp\Modules\Import\Controller\File\Parser\Manager as FileParser;

defined( 'WPIE__FILE__' ) || exit;


class Process {

        
        public static function duplicate( $processType = 'regular' ) {

                return Settings::duplicate( [
                                "process"      => "import",
                                "status"       => "init",
                                "total"        => 0,
                                "process_type" => $processType,
                                "name"         => "",
                                "user"         => Settings::get( "user" ),
                        ] );

        }

        
        public static function failed( $error = '' ) {

                Settings::set( 'status', 'failed' );

                Settings::setOption( 'error', $error );
        }

        
        public static function init() {

                return self::startProcess();
        }

        
        public static function startProcess() {

                self::start();

                if ( !self::download() ) {
                        return;
                }

                if ( 'local' === Settings::getOption( 'uploder/method' ) ) {
                        return 'completed';
                }

                if ( !self::extract() ) {
                        return;
                }
                if ( !self::parse() ) {
                        return;
                }
                if ( !self::addFilter() ) {
                        return;
                }
                if ( !self::getTotal() ) {
                        return;
                }

                return 'completed';
        }

        
        public static function start() {

                $field = Settings::get( 'id' ) . '/reinit';

                if ( 'init' === Settings::getOption( $field ) ) {
                        return;
                }

                Settings::setOptions( [
                        $field        => 'init',
                        'file/parser' => '',
                        'new'         => ''
                ] );
        }

        
        public static function download() {

                if ( 'completed' === Settings::getOption( 'new/download' ) ) {
                        return true;
                }

                $file = Downloader::init();

                if ( \is_wp_error( $file ) ) {
                        self::failed( $file->get_error_message() );
                        return false;
                }

                Settings::setOption( 'new/download', 'completed' );

                return false;
        }

        
        public static function extract() {

                if ( 'completed' === Settings::getOption( 'new/extract' ) ) {
                        return true;
                }

                $filename = Settings::get( 'file' );

                if ( !Helper::isArchive( $filename ) ) {
                        Settings::setOption( 'new/extract', 'completed' );
                        return true;
                }

                $file = Settings::getOption( "file/path" );

                $isSucess = Setup::setFile( $file );

                if ( \is_wp_error( $isSucess ) ) {
                        self::failed( $isSucess->get_error_message() );
                        return false;
                }

                Settings::setOption( 'new/extract', 'completed' );

                return false;
        }

        
        public static function parse() {

                if ( 'completed' === Settings::getOption( 'new/parse' ) ) {
                        return true;
                }

                $parse = FileParser::init();

                if ( \is_wp_error( $parse ) ) {
                        self::failed( $parse->get_error_message() );
                        return false;
                }

                if ( is_array( $parse ) && isset( $parse[ 'status' ] ) && 'completed' === $parse[ 'status' ] ) {
                        Settings::setOption( 'new/parse', 'completed' );
                }

                return false;
        }

        
        public static function addFilter() {

                if ( 'completed' === Settings::getOption( 'new/filter' ) ) {
                        return true;
                }

                $filter = Filter::init();

                if ( \is_wp_error( $filter ) ) {
                        self::failed( $filter->get_error_message() );
                        return false;
                }

                if ( is_array( $filter ) && isset( $filter[ 'status' ] ) && 'completed' === $filter[ 'status' ] ) {
                        Settings::setOption( 'new/filter', 'completed' );
                }

                return false;
        }

        
        public static function getTotal() {

                if ( 'completed' === Settings::getOption( 'new/total' ) ) {
                        return true;
                }

                $total = Record::get( "getTotal" );

                if ( is_numeric( $total ) ) {
                        Settings::set( 'total', $total );
                }

                Settings::setOption( 'new/total', 'completed' );

                return false;
        }
}
