<?php

namespace WpieApp\Modules\Import;

use WpieApp\Core\Utils\Cron;
use WpieApp\Providers\Middleware as BaseMiddleware;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\View\Steps;
use WpieApp\Modules\Base\Model\Settings as SettingModel;

defined( 'WPIE__FILE__' ) || exit;


class Middleware extends BaseMiddleware {

        
        public function boot() {

                // add menu...
                $this->createMenu( __( 'Import', 'wp-import-export' ), $this->getAssets(), 20 );
        }

        
        public function getAssets() {

                $moduleURL = Helper::activeModuleURL();

                return [
                        'styles'  => [
                                Helper::PLUGIN_PREFIX . '-import' => $moduleURL . '/assets/css/import.css'
                        ],
                        'scripts' => [
                                "plupload"                            => "",
                                Helper::PLUGIN_PREFIX . 'import'      => [
                                        "src"  => $moduleURL . '/assets/js/import.js',
                                        "deps" => [ 'jquery' ],
                                ],
                                Helper::PLUGIN_PREFIX . 'uploader'    => [
                                        "src"  => $moduleURL . '/assets/js/uploader.js',
                                        "deps" => [ 'jquery', 'plupload', Helper::PLUGIN_PREFIX . 'admin', Helper::PLUGIN_PREFIX . 'import' ],
                                ],
                                Helper::PLUGIN_PREFIX . 'downloader'  => [
                                        "src"  => $moduleURL . '/assets/js/downloader.js',
                                        "deps" => [ 'jquery', Helper::PLUGIN_PREFIX . 'admin', Helper::PLUGIN_PREFIX . 'import' ],
                                ],
                                Helper::PLUGIN_PREFIX . 'filemanager' => [
                                        "src"  => $moduleURL . '/assets/js/filemanager.js',
                                        "deps" => [ 'jquery', Helper::PLUGIN_PREFIX . 'admin', Helper::PLUGIN_PREFIX . 'import' ],
                                ],
                                Helper::PLUGIN_PREFIX . 'settings'    => [
                                        "src"  => $moduleURL . '/assets/js/settings.js',
                                        "deps" => [ 'jquery', Helper::PLUGIN_PREFIX . 'admin', Helper::PLUGIN_PREFIX . 'import' ],
                                ],
                        ]
                ];
        }

        
        public function addJsonData() {

                Helper::addJsonData( "conditions", Helper::getConditionList() );
                Helper::addJsonData( "supportedExt", Helper::getSupportedExt() );
                Helper::addJsonData( "fileExt", Helper::getSupportedFileExt() );
                Helper::addJsonData( "compressExt", Helper::getSupportedCompressExt() );
                Helper::addJsonData( "steps", Steps::get() );
                Helper::addJsonData( "settings", SettingModel::getAll() );
                Helper::addJsonData( "maxUploadSize", \size_format( self::getUploadSize() ) );
                Helper::addJsonData( "isCronActive", Cron::isActive() );
        }

        
        public function getUploadSize() {

                $max = \wp_max_upload_size();

                if ( $max >= (10 * MB_IN_BYTES) ) {
                        return 10 * MB_IN_BYTES;
                }
                if ( $max >= (2 * MB_IN_BYTES) ) {
                        return $max * 0.8;
                }

                return $max;
        }
}
