<?php



namespace WpieApp\Modules\Import\View\FileSetup;

use WpieApp\Modules\Import\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class ExistingFile {

        
        public static function getBlocks() {

                $fileList = Helper::getFilesystem()->dirlist( WPIE_UPLOAD_TEMP_DIR );

                $files = Helper::isNonEmptyArray( $fileList ) ? array_filter( array_keys( $fileList ), [ Helper::class, 'isSupportedFile' ] ) : [];

                
                return \apply_filters(
                        'Wpie/Modules/Import/View/FileSetup/ExistingFile',
                        [
                                "title"  => __( 'Existing file', 'wp-import-export' ),
                                "desc"   => __( 'From temp directory', 'wp-import-export' ),
                                "order"  => 40,
                                "notes"  => self::getNotes(),
                                "fields" => [
                                        "select-file" => [
                                                "order"      => 5,
                                                "label"      => __( 'Choose File', 'wp-import-export' ),
                                                "sub-fields" => [
                                                        "file-list"     => [
                                                                "type"        => "select",
                                                                "placeholder" => "Select any file",
                                                                "order"       => 5,
                                                                "name"        => "choices",
                                                                "default"     => [],
                                                                "description" => __( 'Use existing file', 'wp-import-export' ),
                                                                "choices"     => Helper::safeArrayCombine( $files, $files ),
                                                                "class"       => 'wpie-use-existing-file',
                                                                "hint"        => [
                                                                        [ 'text' => __( 'Use file from', 'wp-import-export' ) . ' ' . WPIE_UPLOAD_TEMP_DIR ],
                                                                        [ 'text' => __( 'Add the file to the temporary directory, and it will appear in this list', 'wp-import-export' ) ],
                                                                        [ 'text' => __( 'Best suited for uploading large files', 'wp-import-export' ) ],
                                                                ]
                                                        ],
                                                        "submit-button" => [
                                                                "type"       => "button",
                                                                "order"      => 120,
                                                                "label"      => __( 'Confirm', 'wp-import-export' ),
                                                                "icon-class" => "fa-solid fa-check",
                                                                "class"      => "wpie-use-existing-file-btn btn-primary",
                                                        ]
                                                ]
                                        ]
                                ]
                        ]
                );
        }

        
        public static function getNotes() {

                
                return \apply_filters(
                        'Wpie/Modules/Import/View/FileSetup/ExistingFile/Notes',
                        [
                                [
                                        "type"       => "info",
                                        "icon-class" => "fa-solid fa-circle-info ",
                                        "class"      => "mb-4 wpie-info-alert",
                                        "text"       => sprintf(
                                                /* translators: Link to the use existing file documentation. */
                                                __(
                                                        '<a href="%s" target="_blank" class="wpie-info-alert-link">Click here</a> to learn the step-by-step process for using existing files',
                                                        'wp-import-export'
                                                ),
                                                \esc_url( WPIE_DOC_URL . 'use-existing-file' )
                                        )
                                ]
                        ]
                );
        }
}
