<?php



namespace WpieApp\Modules\Schedules\Controller;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Logs\Controller\ManageLog;
use WpieApp\Modules\Export\Controller\Settings as ExportSettings;
use WpieApp\Modules\Import\Controller\Settings as ImportSettings;
use WpieApp\Modules\Export\Controller\Schedule as ExportSchedule;
use WpieApp\Modules\Import\Controller\Schedule as ImportSchedule;

defined( 'WPIE__FILE__' ) || exit;


class Ajax {

        
        public static function updateStatus() {

                $id = Helper::toInt( Helper::_post( "id" ) );

                if ( $id < 1 ) {
                        Helper::ajaxError( __( 'Schedule not found', 'wp-import-export' ) );
                }

                $status = Helper::sanitizeKey( Helper::_post( "status" ) );

                DB::wpdb()->query( DB::wpdb()->prepare( "UPDATE " . DB::getPluginTable() . " SET `status` = %s where `id` = %d", $status, $id ) );

                $msg = ($status === "paused" ? __( 'Schedule Paused', 'wp-import-export' ) : __( 'Schedule Resume', 'wp-import-export' ));

                $time = \wp_next_scheduled( 'WpieApp/Schedule/Start', [ $id ] );

                $nextRun     = ($status === "paused" ? "" : Date::getLocalByTimestamp( $time ));
                $nextRunTime = ($status === "paused" ? "" : __( 'In', 'wp-import-export' ) . ' ' . \human_time_diff( time(), $time ));

                self::addLogMsg( $id, $msg );

                Helper::ajaxSuccess( [ 'msg' => $msg, "nextRun" => $nextRun, "nextRunTime" => $nextRunTime ] );
        }

        
        public static function addLogMsg( $id = 0, $msg = '' ) {

                $process = DB::wpdb()->get_var( DB::wpdb()->prepare( "SELECT `process` FROM " . DB::getPluginTable() . " where `id` = %d", $id ) );

                if ( $process === "export" ) {
                        return ExportSchedule::addLogMsg( $id, $msg );
                } elseif ( $process === "import" ) {
                        return ImportSchedule::addLogMsg( $id, $msg );
                }
        }

        
        public static function removeSchedule() {

                $ids = Helper::_post( "ids" );

                Event::remove( $ids );

                if ( ManageLog::removeLogs( $ids ) === false ) {
                        Helper::ajaxError( __( 'Something Wrong', 'wp-import-export' ) );
                }

                Helper::ajaxSuccess( __( 'Schedule Successfully deleted', 'wp-import-export' ) );
        }

        
        public static function fixSchedule() {

                $id = Helper::toInt( Helper::_post( "id" ) );

                if ( $id < 1 ) {
                        Helper::ajaxError( __( 'Schedule not found', 'wp-import-export' ) );
                }

                $process = DB::wpdb()->get_var( DB::wpdb()->prepare( "SELECT `process` FROM " . DB::getPluginTable() . " where `id` = %d AND `process_type` = 'schedule'", $id ) );

                if ( !Helper::isNonEmptyStr( $process ) ) {
                        Helper::ajaxError( __( 'Schedule not found', 'wp-import-export' ) );
                }

                if ( false !== \wp_next_scheduled( 'WpieApp/Schedule/Start', [ $id ] ) ) {
                        Helper::ajaxError( __( 'Unable to fix the schedule', 'wp-import-export' ) );
                }

                if ( $process === "export" ) {

                        ExportSettings::autoLoad();

                        $interval = ExportSettings::getOption( 'schedule/interval' );

                        $start = ExportSettings::getOption( 'schedule/start' );
                } elseif ( $process === "import" ) {

                        ImportSettings::autoLoad();

                        $interval = ImportSettings::getOption( 'schedule/interval' );

                        $start = ImportSettings::getOption( 'schedule/start' );
                }

                $isAdded = Event::add( $id, $interval, $start );

                if ( \is_wp_error( $isAdded ) ) {
                        Helper::ajaxError( $isAdded );
                }

                $time = \wp_next_scheduled( 'WpieApp/Schedule/Start', [ $id ] );

                $nextRun     = Date::getLocalByTimestamp( $time );
                $nextRunTime = __( 'In', 'wp-import-export' ) . ' ' . \human_time_diff( time(), $time );

                $msg = __( 'The scheduling issue has been resolved successfully', 'wp-import-export' );

                self::addLogMsg( $id, $msg );

                Helper::ajaxSuccess( [ 'msg' => $msg, "nextRun" => $nextRun, "nextRunTime" => $nextRunTime ] );
        }

        
        public static function saveSettings() {

                $overloading = Helper::_post( "overloading" );

                Helper::setOption( 'schedule-overloading', ($overloading !== 'no' ? 'yes' : 'no' ) );

                Helper::ajaxSuccess();
        }

        
        public static function downloadLog() {

                $id = Helper::toInt( Helper::_post( "id" ) );

                if ( $id < 1 ) {
                        Helper::ajaxError( __( 'Schedule not found', 'wp-import-export' ) );
                }

                $process = DB::wpdb()->get_var( DB::wpdb()->prepare( "SELECT `process` FROM " . DB::getPluginTable() . " where `id` = %d AND `process_type` = 'schedule'", $id ) );

                if ( !Helper::isNonEmptyStr( $process ) ) {
                        Helper::ajaxError( __( 'Schedule not found', 'wp-import-export' ) );
                }

                $path = '';

                if ( $process === "export" ) {

                        ExportSettings::autoLoad();

                        $path = ExportSettings::getLogFilePath();
                } elseif ( $process === "import" ) {

                        ImportSettings::autoLoad();

                        $path = ImportSettings::getLogFilePath();
                }

                Helper::download( $path );
        }
}
