<?php




namespace WpieApp\Modules\Security\Controller;

use WP_Error;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Utils\DB;

defined( 'WPIE__FILE__' ) || exit;


class User {

        
        public static function updateUserAccess( $emails, $permissions ) {

                if ( !Helper::isNonEmptyStr( $emails ) ) {
                        return new WP_Error( 'wpieError', __( 'Emails are empty', 'wp-import-export' ) );
                }

                if ( !Helper::isNonEmptyArray( $permissions ) ) {
                        return new WP_Error( 'wpieError', __( 'Permisions are missing', 'wp-import-export' ) );
                }

                $emails = Helper::strToArr( $emails );

                $placeholders = implode( ', ', array_fill( 0, count( $emails ), '%s' ) );

                $users = DB::wpdb()->get_col( DB::wpdb()->prepare( "SELECT `ID` FROM " . DB::wpdb()->users . " WHERE `user_email` IN (" . $placeholders . ")", $emails ) );

                if ( !Helper::isNonEmptyArray( $users ) ) {
                        return __( 'Permissions successfully updated', 'wp-import-export' );
                }

                foreach ( $users as $id ) {
                        $user = \get_user_by( "id", $id );
                        self::updateAccess( $user, $permissions );
                        unset( $user );
                }

                return __( 'Permissions successfully updated', 'wp-import-export' );
        }

        
        public static function updateUserRoleAccess( $role, $permissions ) {

                if ( !Helper::isNonEmptyStr( $role ) ) {
                        return new WP_Error( 'wpieError', __( 'User Role is empty', 'wp-import-export' ) );
                }

                if ( !Helper::isNonEmptyArray( $permissions ) ) {
                        return new WP_Error( 'wpieError', __( 'Permisions are missing', 'wp-import-export' ) );
                }

                $userRole = \get_role( $role );

                if ( is_null( $userRole ) ) {
                        return new WP_Error( 'wpieError', __( 'User Role is not founded', 'wp-import-export' ) );
                }

                self::updateAccess( $userRole, $permissions );

                return __( 'Permissions successfully updated', 'wp-import-export' );
        }

        
        private static function updateAccess( $user, $permissions ) {

                foreach ( $permissions as $permission => $hasAccess ) {

                        if ( !Helper::strStartsWith( "wpie", $permission ) ) {
                                continue;
                        }

                        if ( Helper::toInt( $hasAccess ) === 1 && !$user->has_cap( $permission ) ) {
                                $user->add_cap( $permission );
                        } elseif ( Helper::toInt( $hasAccess ) !== 1 && $user->has_cap( $permission ) ) {
                                $user->remove_cap( $permission );
                        }
                }
        }

        
        public static function getRoleAccess( $role, $permissions ) {

                if ( !Helper::isNonEmptyStr( $role ) ) {
                        return new WP_Error( 'wpieError', __( 'User Role is empty', 'wp-import-export' ) );
                }

                if ( !Helper::isNonEmptyArray( $permissions ) ) {
                        return new WP_Error( 'wpieError', __( 'Permisions are missing', 'wp-import-export' ) );
                }

                $userRole = \get_role( $role );

                if ( is_null( $userRole ) ) {
                        return new WP_Error( 'wpieError', __( 'User Role is not founded', 'wp-import-export' ) );
                }

                $caps = [];

                foreach ( $permissions as $permission ) {

                        $caps[ $permission ] = $userRole->has_cap( $permission ) ? 1 : 0;
                }

                return $caps;
        }

}
