<?php



namespace WpieApp\Modules\Tools\Controller;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Utils\FileUploadManager;
use WpieApp\Modules\Logs\Controller\Ajax as LogController;

defined( 'WPIE__FILE__' ) || exit;


class Ajax {

        
        public static function removeLogs() {

                LogController::removeLogs();
        }

        
        public static function deleteOnUninstall() {

                Helper::setOption( 'delete-on-uninstall', (1 === Helper::toInt( Helper::_post( "delete-on-uninstall" ) ) ? '1' : '0' ) );

                Helper::ajaxSuccess( __( 'Settings saved successfully', 'wp-import-export' ) );
        }

        
        public static function downloadSettings() {

                $ids = Helper::jsonDecode( Helper::_post( "ids" ), true );

                if ( is_wp_error( $ids ) ) {
                        Helper::ajaxError( $ids );
                }

                if ( !Helper::isNonEmptyArray( $ids ) ) {
                        Helper::ajaxError( __( 'Settings not found', 'wp-import-export' ) );
                }

                $placeholders = implode( ', ', array_fill( 0, count( $ids ), '%d' ) );

                $data = DB::wpdb()->get_results( DB::wpdb()->prepare( "SELECT `category` ,`content_type`,`process`,`options`,`name`,`user`,`created_date`,`updated_date` FROM " . DB::getPluginTable() . " WHERE `id` IN ($placeholders)", $ids ), ARRAY_A );

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return true;
                }

                $filename = 'settings.json';

                // Convert the JSON object to a string
                $jsonString = Helper::jsonEncode( $data );

                // Set the appropriate headers for file download
                header( 'Content-Description: File Transfer' );
                header( 'Content-Type: application/json' );
                header( 'Content-Disposition: attachment; filename="' . $filename . '"' );
                header( 'Expires: 0' );
                header( 'Cache-Control: must-revalidate' );
                header( 'Pragma: public' );
                header( 'Content-Length: ' . strlen( $jsonString ) );

                // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                echo $jsonString;
                die();
        }

        
        public static function uploadSettings() {

                $data = FileUploadManager::read( 'file' );

                if ( \is_wp_error( $data ) ) {
                        Helper::ajaxError( $data );
                }

                if ( !Helper::isNonEmptyStr( $data ) ) {
                        Helper::ajaxError( __( 'File is empty', 'wp-import-export' ) );
                }

                $settings = Helper::jsonDecode( $data, true );

                $names = [];

                foreach ( $settings as $setting ) {
                        $name = isset( $setting[ 'name' ] ) ? $setting[ 'name' ] : "";

                        if ( !Helper::isNonEmptyStr( $name ) ) {
                                continue;
                        }
                        $names[] = $name;
                }

                if ( !Helper::isNonEmptyArray( $names ) ) {
                        Helper::ajaxError( __( 'Setting names are required', 'wp-import-export' ) );
                }


                $placeholders = implode( ', ', array_fill( 0, count( $names ), '%s' ) );

                $dbnames = DB::wpdb()->get_col( DB::wpdb()->prepare( "SELECT `name` FROM " . DB::getPluginTable() . " WHERE `process_type` = 'setting' AND `name` IN ($placeholders)", $names ) );

                $user = Helper::getCurrentUserEmail();

                $current_time = Date::now();

                foreach ( $settings as $setting ) {

                        $name = isset( $setting[ 'name' ] ) ? $setting[ 'name' ] : "";

                        if ( Helper::isNonEmptyArray( $dbnames ) && in_array( $name, $dbnames ) ) {
                                continue;
                        }

                        $settingData = [
                                "category"     => isset( $setting[ 'category' ] ) ? $setting[ 'category' ] : "",
                                "content_type" => isset( $setting[ 'content_type' ] ) ? $setting[ 'content_type' ] : "",
                                "process"      => isset( $setting[ 'process' ] ) ? $setting[ 'process' ] : "",
                                "options"      => isset( $setting[ 'options' ] ) ? $setting[ 'options' ] : "",
                                "process_type" => "setting",
                                "status"       => "completed",
                                "name"         => $name,
                                "user"         => $user,
                                "created_date" => $current_time,
                                "updated_date" => $current_time,
                        ];

                        $placeholders = array_fill( 0, count( $settingData ), '%s' );

                        //insert template data
                        DB::wpdb()->insert( DB::getPluginTable(), $settingData, $placeholders );
                }

                if ( Helper::isNonEmptyArray( $dbnames ) ) {
                        /* translators: %s: Setting names */
                        Helper::ajaxSuccess( sprintf( __( 'Setting Successfully Imported. Except %s', 'wp-import-export' ), implode( ', ', array_unique( $dbnames ) ) ) );
                }

                Helper::ajaxSuccess( __( 'Setting Successfully Imported', 'wp-import-export' ) );
        }
}
